# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'GetBucketServerSideEncryptionConfigurationResult',
    'AwaitableGetBucketServerSideEncryptionConfigurationResult',
    'get_bucket_server_side_encryption_configuration',
    'get_bucket_server_side_encryption_configuration_output',
]

@pulumi.output_type
class GetBucketServerSideEncryptionConfigurationResult:
    """
    A collection of values returned by getBucketServerSideEncryptionConfiguration.
    """
    def __init__(__self__, bucket=None, bucket_server_side_encryption_configuration_id=None, id=None, rules=None):
        if bucket and not isinstance(bucket, str):
            raise TypeError("Expected argument 'bucket' to be a str")
        pulumi.set(__self__, "bucket", bucket)
        if bucket_server_side_encryption_configuration_id and not isinstance(bucket_server_side_encryption_configuration_id, str):
            raise TypeError("Expected argument 'bucket_server_side_encryption_configuration_id' to be a str")
        pulumi.set(__self__, "bucket_server_side_encryption_configuration_id", bucket_server_side_encryption_configuration_id)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if rules and not isinstance(rules, list):
            raise TypeError("Expected argument 'rules' to be a list")
        pulumi.set(__self__, "rules", rules)

    @_builtins.property
    @pulumi.getter
    def bucket(self) -> Optional[_builtins.str]:
        """
        (String) The bucket's name or regional ID.
        """
        return pulumi.get(self, "bucket")

    @_builtins.property
    @pulumi.getter(name="bucketServerSideEncryptionConfigurationId")
    def bucket_server_side_encryption_configuration_id(self) -> Optional[_builtins.str]:
        return pulumi.get(self, "bucket_server_side_encryption_configuration_id")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter
    def rules(self) -> Sequence['outputs.GetBucketServerSideEncryptionConfigurationRuleResult']:
        """
        (Set of Object) Set of server-side encryption configuration rules.
        """
        return pulumi.get(self, "rules")


class AwaitableGetBucketServerSideEncryptionConfigurationResult(GetBucketServerSideEncryptionConfigurationResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetBucketServerSideEncryptionConfigurationResult(
            bucket=self.bucket,
            bucket_server_side_encryption_configuration_id=self.bucket_server_side_encryption_configuration_id,
            id=self.id,
            rules=self.rules)


def get_bucket_server_side_encryption_configuration(bucket: Optional[_builtins.str] = None,
                                                    bucket_server_side_encryption_configuration_id: Optional[_builtins.str] = None,
                                                    opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetBucketServerSideEncryptionConfigurationResult:
    """
    Get information about a bucket server side encryption configuration. This data source allows you to retrieve information about the server-side encryption configuration of a bucket.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_scaleway as scaleway

    # Get by ID
    by_id = scaleway.object.get_bucket_server_side_encryption_configuration(bucket_server_side_encryption_configuration_id=main["id"])
    ```

    ```python
    import pulumi
    import pulumi_scaleway as scaleway

    # Get by Bucket Name
    by_bucket = scaleway.object.get_bucket_server_side_encryption_configuration(bucket=main["name"])
    ```


    :param _builtins.str bucket: The bucket's name or regional ID. Conflicts with `bucket_server_side_encryption_configuration_id`.
    :param _builtins.str bucket_server_side_encryption_configuration_id: The ID of the bucket server side encryption configuration. Conflicts with `bucket`.
    """
    __args__ = dict()
    __args__['bucket'] = bucket
    __args__['bucketServerSideEncryptionConfigurationId'] = bucket_server_side_encryption_configuration_id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('scaleway:object/getBucketServerSideEncryptionConfiguration:getBucketServerSideEncryptionConfiguration', __args__, opts=opts, typ=GetBucketServerSideEncryptionConfigurationResult).value

    return AwaitableGetBucketServerSideEncryptionConfigurationResult(
        bucket=pulumi.get(__ret__, 'bucket'),
        bucket_server_side_encryption_configuration_id=pulumi.get(__ret__, 'bucket_server_side_encryption_configuration_id'),
        id=pulumi.get(__ret__, 'id'),
        rules=pulumi.get(__ret__, 'rules'))
def get_bucket_server_side_encryption_configuration_output(bucket: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                                                           bucket_server_side_encryption_configuration_id: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                                                           opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetBucketServerSideEncryptionConfigurationResult]:
    """
    Get information about a bucket server side encryption configuration. This data source allows you to retrieve information about the server-side encryption configuration of a bucket.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_scaleway as scaleway

    # Get by ID
    by_id = scaleway.object.get_bucket_server_side_encryption_configuration(bucket_server_side_encryption_configuration_id=main["id"])
    ```

    ```python
    import pulumi
    import pulumi_scaleway as scaleway

    # Get by Bucket Name
    by_bucket = scaleway.object.get_bucket_server_side_encryption_configuration(bucket=main["name"])
    ```


    :param _builtins.str bucket: The bucket's name or regional ID. Conflicts with `bucket_server_side_encryption_configuration_id`.
    :param _builtins.str bucket_server_side_encryption_configuration_id: The ID of the bucket server side encryption configuration. Conflicts with `bucket`.
    """
    __args__ = dict()
    __args__['bucket'] = bucket
    __args__['bucketServerSideEncryptionConfigurationId'] = bucket_server_side_encryption_configuration_id
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('scaleway:object/getBucketServerSideEncryptionConfiguration:getBucketServerSideEncryptionConfiguration', __args__, opts=opts, typ=GetBucketServerSideEncryptionConfigurationResult)
    return __ret__.apply(lambda __response__: GetBucketServerSideEncryptionConfigurationResult(
        bucket=pulumi.get(__response__, 'bucket'),
        bucket_server_side_encryption_configuration_id=pulumi.get(__response__, 'bucket_server_side_encryption_configuration_id'),
        id=pulumi.get(__response__, 'id'),
        rules=pulumi.get(__response__, 'rules')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'GetPolicyResult',
    'AwaitableGetPolicyResult',
    'get_policy',
    'get_policy_output',
]

@pulumi.output_type
class GetPolicyResult:
    """
    A collection of values returned by getPolicy.
    """
    def __init__(__self__, application_id=None, created_at=None, description=None, editable=None, group_id=None, id=None, name=None, no_principal=None, organization_id=None, policy_id=None, rules=None, tags=None, updated_at=None, user_id=None):
        if application_id and not isinstance(application_id, str):
            raise TypeError("Expected argument 'application_id' to be a str")
        pulumi.set(__self__, "application_id", application_id)
        if created_at and not isinstance(created_at, str):
            raise TypeError("Expected argument 'created_at' to be a str")
        pulumi.set(__self__, "created_at", created_at)
        if description and not isinstance(description, str):
            raise TypeError("Expected argument 'description' to be a str")
        pulumi.set(__self__, "description", description)
        if editable and not isinstance(editable, bool):
            raise TypeError("Expected argument 'editable' to be a bool")
        pulumi.set(__self__, "editable", editable)
        if group_id and not isinstance(group_id, str):
            raise TypeError("Expected argument 'group_id' to be a str")
        pulumi.set(__self__, "group_id", group_id)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if no_principal and not isinstance(no_principal, bool):
            raise TypeError("Expected argument 'no_principal' to be a bool")
        pulumi.set(__self__, "no_principal", no_principal)
        if organization_id and not isinstance(organization_id, str):
            raise TypeError("Expected argument 'organization_id' to be a str")
        pulumi.set(__self__, "organization_id", organization_id)
        if policy_id and not isinstance(policy_id, str):
            raise TypeError("Expected argument 'policy_id' to be a str")
        pulumi.set(__self__, "policy_id", policy_id)
        if rules and not isinstance(rules, list):
            raise TypeError("Expected argument 'rules' to be a list")
        pulumi.set(__self__, "rules", rules)
        if tags and not isinstance(tags, list):
            raise TypeError("Expected argument 'tags' to be a list")
        pulumi.set(__self__, "tags", tags)
        if updated_at and not isinstance(updated_at, str):
            raise TypeError("Expected argument 'updated_at' to be a str")
        pulumi.set(__self__, "updated_at", updated_at)
        if user_id and not isinstance(user_id, str):
            raise TypeError("Expected argument 'user_id' to be a str")
        pulumi.set(__self__, "user_id", user_id)

    @_builtins.property
    @pulumi.getter(name="applicationId")
    def application_id(self) -> _builtins.str:
        """
        ID of the application the policy is linked to
        """
        return pulumi.get(self, "application_id")

    @_builtins.property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> _builtins.str:
        """
        The date and time of the creation of the policy.
        """
        return pulumi.get(self, "created_at")

    @_builtins.property
    @pulumi.getter
    def description(self) -> _builtins.str:
        """
        The description of the IAM policy.
        """
        return pulumi.get(self, "description")

    @_builtins.property
    @pulumi.getter
    def editable(self) -> _builtins.bool:
        """
        Whether the policy is editable.
        """
        return pulumi.get(self, "editable")

    @_builtins.property
    @pulumi.getter(name="groupId")
    def group_id(self) -> _builtins.str:
        """
        ID of the group the policy is linked to
        """
        return pulumi.get(self, "group_id")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[_builtins.str]:
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter(name="noPrincipal")
    def no_principal(self) -> _builtins.bool:
        """
        If the policy doesn't apply to a principal.
        """
        return pulumi.get(self, "no_principal")

    @_builtins.property
    @pulumi.getter(name="organizationId")
    def organization_id(self) -> _builtins.str:
        """
        ID of organization scoped to the rule.
        """
        return pulumi.get(self, "organization_id")

    @_builtins.property
    @pulumi.getter(name="policyId")
    def policy_id(self) -> Optional[_builtins.str]:
        return pulumi.get(self, "policy_id")

    @_builtins.property
    @pulumi.getter
    def rules(self) -> Sequence['outputs.GetPolicyRuleResult']:
        """
        List of rules in the policy.
        """
        return pulumi.get(self, "rules")

    @_builtins.property
    @pulumi.getter
    def tags(self) -> Sequence[_builtins.str]:
        """
        The tags associated with the IAM policy.
        """
        return pulumi.get(self, "tags")

    @_builtins.property
    @pulumi.getter(name="updatedAt")
    def updated_at(self) -> _builtins.str:
        """
        The date and time of the last update of the policy.
        """
        return pulumi.get(self, "updated_at")

    @_builtins.property
    @pulumi.getter(name="userId")
    def user_id(self) -> _builtins.str:
        """
        ID of the user the policy is linked to
        """
        return pulumi.get(self, "user_id")


class AwaitableGetPolicyResult(GetPolicyResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetPolicyResult(
            application_id=self.application_id,
            created_at=self.created_at,
            description=self.description,
            editable=self.editable,
            group_id=self.group_id,
            id=self.id,
            name=self.name,
            no_principal=self.no_principal,
            organization_id=self.organization_id,
            policy_id=self.policy_id,
            rules=self.rules,
            tags=self.tags,
            updated_at=self.updated_at,
            user_id=self.user_id)


def get_policy(name: Optional[_builtins.str] = None,
               policy_id: Optional[_builtins.str] = None,
               opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetPolicyResult:
    """
    Use this data source to get information on an existing IAM policy based on its ID.
    For more information refer to the [IAM API documentation](https://developers.scaleway.com/en/products/iam/api/).

    ## Example Usage

    ```python
    import pulumi
    import pulumi_scaleway as scaleway

    # Get policy by id
    find_by_id = scaleway.iam.get_policy(policy_id="11111111-1111-1111-1111-111111111111")
    # Get policy by name
    find_by_name = scaleway.iam.get_policy(name="my_policy")
    ```


    :param _builtins.str name: The name of the IAM policy.
    :param _builtins.str policy_id: The ID of the IAM policy.
           
           > **Note** You must specify at least one: `name` and/or `policy_id`.
    """
    __args__ = dict()
    __args__['name'] = name
    __args__['policyId'] = policy_id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('scaleway:iam/getPolicy:getPolicy', __args__, opts=opts, typ=GetPolicyResult).value

    return AwaitableGetPolicyResult(
        application_id=pulumi.get(__ret__, 'application_id'),
        created_at=pulumi.get(__ret__, 'created_at'),
        description=pulumi.get(__ret__, 'description'),
        editable=pulumi.get(__ret__, 'editable'),
        group_id=pulumi.get(__ret__, 'group_id'),
        id=pulumi.get(__ret__, 'id'),
        name=pulumi.get(__ret__, 'name'),
        no_principal=pulumi.get(__ret__, 'no_principal'),
        organization_id=pulumi.get(__ret__, 'organization_id'),
        policy_id=pulumi.get(__ret__, 'policy_id'),
        rules=pulumi.get(__ret__, 'rules'),
        tags=pulumi.get(__ret__, 'tags'),
        updated_at=pulumi.get(__ret__, 'updated_at'),
        user_id=pulumi.get(__ret__, 'user_id'))
def get_policy_output(name: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                      policy_id: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                      opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetPolicyResult]:
    """
    Use this data source to get information on an existing IAM policy based on its ID.
    For more information refer to the [IAM API documentation](https://developers.scaleway.com/en/products/iam/api/).

    ## Example Usage

    ```python
    import pulumi
    import pulumi_scaleway as scaleway

    # Get policy by id
    find_by_id = scaleway.iam.get_policy(policy_id="11111111-1111-1111-1111-111111111111")
    # Get policy by name
    find_by_name = scaleway.iam.get_policy(name="my_policy")
    ```


    :param _builtins.str name: The name of the IAM policy.
    :param _builtins.str policy_id: The ID of the IAM policy.
           
           > **Note** You must specify at least one: `name` and/or `policy_id`.
    """
    __args__ = dict()
    __args__['name'] = name
    __args__['policyId'] = policy_id
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('scaleway:iam/getPolicy:getPolicy', __args__, opts=opts, typ=GetPolicyResult)
    return __ret__.apply(lambda __response__: GetPolicyResult(
        application_id=pulumi.get(__response__, 'application_id'),
        created_at=pulumi.get(__response__, 'created_at'),
        description=pulumi.get(__response__, 'description'),
        editable=pulumi.get(__response__, 'editable'),
        group_id=pulumi.get(__response__, 'group_id'),
        id=pulumi.get(__response__, 'id'),
        name=pulumi.get(__response__, 'name'),
        no_principal=pulumi.get(__response__, 'no_principal'),
        organization_id=pulumi.get(__response__, 'organization_id'),
        policy_id=pulumi.get(__response__, 'policy_id'),
        rules=pulumi.get(__response__, 'rules'),
        tags=pulumi.get(__response__, 'tags'),
        updated_at=pulumi.get(__response__, 'updated_at'),
        user_id=pulumi.get(__response__, 'user_id')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['SamlArgs', 'Saml']

@pulumi.input_type
class SamlArgs:
    def __init__(__self__, *,
                 organization_id: Optional[pulumi.Input[_builtins.str]] = None):
        """
        The set of arguments for constructing a Saml resource.
        :param pulumi.Input[_builtins.str] organization_id: The organization ID. If not provided, the default organization ID will be used.
        """
        if organization_id is not None:
            pulumi.set(__self__, "organization_id", organization_id)

    @_builtins.property
    @pulumi.getter(name="organizationId")
    def organization_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The organization ID. If not provided, the default organization ID will be used.
        """
        return pulumi.get(self, "organization_id")

    @organization_id.setter
    def organization_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "organization_id", value)


@pulumi.input_type
class _SamlState:
    def __init__(__self__, *,
                 entity_id: Optional[pulumi.Input[_builtins.str]] = None,
                 organization_id: Optional[pulumi.Input[_builtins.str]] = None,
                 service_provider: Optional[pulumi.Input['SamlServiceProviderArgs']] = None,
                 single_sign_on_url: Optional[pulumi.Input[_builtins.str]] = None,
                 status: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering Saml resources.
        :param pulumi.Input[_builtins.str] entity_id: (Computed) The entity ID of the Service Provider.
        :param pulumi.Input[_builtins.str] organization_id: The organization ID. If not provided, the default organization ID will be used.
        :param pulumi.Input['SamlServiceProviderArgs'] service_provider: (Computed) The Service Provider information. It contains:
        :param pulumi.Input[_builtins.str] single_sign_on_url: (Computed) The single sign-on URL of the SAML Identity Provider.
        :param pulumi.Input[_builtins.str] status: (Computed) The status of the SAML configuration.
        """
        if entity_id is not None:
            pulumi.set(__self__, "entity_id", entity_id)
        if organization_id is not None:
            pulumi.set(__self__, "organization_id", organization_id)
        if service_provider is not None:
            pulumi.set(__self__, "service_provider", service_provider)
        if single_sign_on_url is not None:
            pulumi.set(__self__, "single_sign_on_url", single_sign_on_url)
        if status is not None:
            pulumi.set(__self__, "status", status)

    @_builtins.property
    @pulumi.getter(name="entityId")
    def entity_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        (Computed) The entity ID of the Service Provider.
        """
        return pulumi.get(self, "entity_id")

    @entity_id.setter
    def entity_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "entity_id", value)

    @_builtins.property
    @pulumi.getter(name="organizationId")
    def organization_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The organization ID. If not provided, the default organization ID will be used.
        """
        return pulumi.get(self, "organization_id")

    @organization_id.setter
    def organization_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "organization_id", value)

    @_builtins.property
    @pulumi.getter(name="serviceProvider")
    def service_provider(self) -> Optional[pulumi.Input['SamlServiceProviderArgs']]:
        """
        (Computed) The Service Provider information. It contains:
        """
        return pulumi.get(self, "service_provider")

    @service_provider.setter
    def service_provider(self, value: Optional[pulumi.Input['SamlServiceProviderArgs']]):
        pulumi.set(self, "service_provider", value)

    @_builtins.property
    @pulumi.getter(name="singleSignOnUrl")
    def single_sign_on_url(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        (Computed) The single sign-on URL of the SAML Identity Provider.
        """
        return pulumi.get(self, "single_sign_on_url")

    @single_sign_on_url.setter
    def single_sign_on_url(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "single_sign_on_url", value)

    @_builtins.property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        (Computed) The status of the SAML configuration.
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "status", value)


@pulumi.type_token("scaleway:iam/saml:Saml")
class Saml(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 organization_id: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        Manages SAML activation for an organization. SAML (Security Assertion Markup Language) is an open standard for exchanging authentication and authorization data between parties, specifically between an identity provider and a service provider. This resource allows you to enable and disable SAML-based single sign-on for your Scaleway organization.

        For configuring SAML parameters (`entity_id` and `single_sign_on_url`), use the `scaleway_iam_update_saml_configuration` action.

        ## Example Usage

        ```python
        import pulumi
        import pulumiverse_scaleway as scaleway

        ### Enable IAM SAML for an organization
        main = scaleway.iam.Saml("main", organization_id="11111111-1111-1111-1111-111111111111")
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] organization_id: The organization ID. If not provided, the default organization ID will be used.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: Optional[SamlArgs] = None,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Manages SAML activation for an organization. SAML (Security Assertion Markup Language) is an open standard for exchanging authentication and authorization data between parties, specifically between an identity provider and a service provider. This resource allows you to enable and disable SAML-based single sign-on for your Scaleway organization.

        For configuring SAML parameters (`entity_id` and `single_sign_on_url`), use the `scaleway_iam_update_saml_configuration` action.

        ## Example Usage

        ```python
        import pulumi
        import pulumiverse_scaleway as scaleway

        ### Enable IAM SAML for an organization
        main = scaleway.iam.Saml("main", organization_id="11111111-1111-1111-1111-111111111111")
        ```

        :param str resource_name: The name of the resource.
        :param SamlArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(SamlArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 organization_id: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = SamlArgs.__new__(SamlArgs)

            __props__.__dict__["organization_id"] = organization_id
            __props__.__dict__["entity_id"] = None
            __props__.__dict__["service_provider"] = None
            __props__.__dict__["single_sign_on_url"] = None
            __props__.__dict__["status"] = None
        super(Saml, __self__).__init__(
            'scaleway:iam/saml:Saml',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            entity_id: Optional[pulumi.Input[_builtins.str]] = None,
            organization_id: Optional[pulumi.Input[_builtins.str]] = None,
            service_provider: Optional[pulumi.Input[Union['SamlServiceProviderArgs', 'SamlServiceProviderArgsDict']]] = None,
            single_sign_on_url: Optional[pulumi.Input[_builtins.str]] = None,
            status: Optional[pulumi.Input[_builtins.str]] = None) -> 'Saml':
        """
        Get an existing Saml resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] entity_id: (Computed) The entity ID of the Service Provider.
        :param pulumi.Input[_builtins.str] organization_id: The organization ID. If not provided, the default organization ID will be used.
        :param pulumi.Input[Union['SamlServiceProviderArgs', 'SamlServiceProviderArgsDict']] service_provider: (Computed) The Service Provider information. It contains:
        :param pulumi.Input[_builtins.str] single_sign_on_url: (Computed) The single sign-on URL of the SAML Identity Provider.
        :param pulumi.Input[_builtins.str] status: (Computed) The status of the SAML configuration.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _SamlState.__new__(_SamlState)

        __props__.__dict__["entity_id"] = entity_id
        __props__.__dict__["organization_id"] = organization_id
        __props__.__dict__["service_provider"] = service_provider
        __props__.__dict__["single_sign_on_url"] = single_sign_on_url
        __props__.__dict__["status"] = status
        return Saml(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="entityId")
    def entity_id(self) -> pulumi.Output[_builtins.str]:
        """
        (Computed) The entity ID of the Service Provider.
        """
        return pulumi.get(self, "entity_id")

    @_builtins.property
    @pulumi.getter(name="organizationId")
    def organization_id(self) -> pulumi.Output[_builtins.str]:
        """
        The organization ID. If not provided, the default organization ID will be used.
        """
        return pulumi.get(self, "organization_id")

    @_builtins.property
    @pulumi.getter(name="serviceProvider")
    def service_provider(self) -> pulumi.Output['outputs.SamlServiceProvider']:
        """
        (Computed) The Service Provider information. It contains:
        """
        return pulumi.get(self, "service_provider")

    @_builtins.property
    @pulumi.getter(name="singleSignOnUrl")
    def single_sign_on_url(self) -> pulumi.Output[_builtins.str]:
        """
        (Computed) The single sign-on URL of the SAML Identity Provider.
        """
        return pulumi.get(self, "single_sign_on_url")

    @_builtins.property
    @pulumi.getter
    def status(self) -> pulumi.Output[_builtins.str]:
        """
        (Computed) The status of the SAML configuration.
        """
        return pulumi.get(self, "status")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = ['EdgeServicesBackendStageArgs', 'EdgeServicesBackendStage']

@pulumi.input_type
class EdgeServicesBackendStageArgs:
    def __init__(__self__, *,
                 pipeline_id: pulumi.Input[_builtins.str],
                 lb_backend_configs: Optional[pulumi.Input[Sequence[pulumi.Input['EdgeServicesBackendStageLbBackendConfigArgs']]]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 s3_backend_config: Optional[pulumi.Input['EdgeServicesBackendStageS3BackendConfigArgs']] = None):
        """
        The set of arguments for constructing a EdgeServicesBackendStage resource.
        :param pulumi.Input[_builtins.str] pipeline_id: The ID of the pipeline.
        :param pulumi.Input[Sequence[pulumi.Input['EdgeServicesBackendStageLbBackendConfigArgs']]] lb_backend_configs: The Scaleway Load Balancer linked to the backend stage.
        :param pulumi.Input[_builtins.str] project_id: `project_id`) The ID of the project the backend stage is associated with.
        :param pulumi.Input['EdgeServicesBackendStageS3BackendConfigArgs'] s3_backend_config: The Scaleway Object Storage origin bucket (S3) linked to the backend stage.
        """
        pulumi.set(__self__, "pipeline_id", pipeline_id)
        if lb_backend_configs is not None:
            pulumi.set(__self__, "lb_backend_configs", lb_backend_configs)
        if project_id is not None:
            pulumi.set(__self__, "project_id", project_id)
        if s3_backend_config is not None:
            pulumi.set(__self__, "s3_backend_config", s3_backend_config)

    @_builtins.property
    @pulumi.getter(name="pipelineId")
    def pipeline_id(self) -> pulumi.Input[_builtins.str]:
        """
        The ID of the pipeline.
        """
        return pulumi.get(self, "pipeline_id")

    @pipeline_id.setter
    def pipeline_id(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "pipeline_id", value)

    @_builtins.property
    @pulumi.getter(name="lbBackendConfigs")
    def lb_backend_configs(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['EdgeServicesBackendStageLbBackendConfigArgs']]]]:
        """
        The Scaleway Load Balancer linked to the backend stage.
        """
        return pulumi.get(self, "lb_backend_configs")

    @lb_backend_configs.setter
    def lb_backend_configs(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['EdgeServicesBackendStageLbBackendConfigArgs']]]]):
        pulumi.set(self, "lb_backend_configs", value)

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        `project_id`) The ID of the project the backend stage is associated with.
        """
        return pulumi.get(self, "project_id")

    @project_id.setter
    def project_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "project_id", value)

    @_builtins.property
    @pulumi.getter(name="s3BackendConfig")
    def s3_backend_config(self) -> Optional[pulumi.Input['EdgeServicesBackendStageS3BackendConfigArgs']]:
        """
        The Scaleway Object Storage origin bucket (S3) linked to the backend stage.
        """
        return pulumi.get(self, "s3_backend_config")

    @s3_backend_config.setter
    def s3_backend_config(self, value: Optional[pulumi.Input['EdgeServicesBackendStageS3BackendConfigArgs']]):
        pulumi.set(self, "s3_backend_config", value)


@pulumi.input_type
class _EdgeServicesBackendStageState:
    def __init__(__self__, *,
                 created_at: Optional[pulumi.Input[_builtins.str]] = None,
                 lb_backend_configs: Optional[pulumi.Input[Sequence[pulumi.Input['EdgeServicesBackendStageLbBackendConfigArgs']]]] = None,
                 pipeline_id: Optional[pulumi.Input[_builtins.str]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 s3_backend_config: Optional[pulumi.Input['EdgeServicesBackendStageS3BackendConfigArgs']] = None,
                 updated_at: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering EdgeServicesBackendStage resources.
        :param pulumi.Input[_builtins.str] created_at: The date and time of the creation of the backend stage.
        :param pulumi.Input[Sequence[pulumi.Input['EdgeServicesBackendStageLbBackendConfigArgs']]] lb_backend_configs: The Scaleway Load Balancer linked to the backend stage.
        :param pulumi.Input[_builtins.str] pipeline_id: The ID of the pipeline.
        :param pulumi.Input[_builtins.str] project_id: `project_id`) The ID of the project the backend stage is associated with.
        :param pulumi.Input['EdgeServicesBackendStageS3BackendConfigArgs'] s3_backend_config: The Scaleway Object Storage origin bucket (S3) linked to the backend stage.
        :param pulumi.Input[_builtins.str] updated_at: The date and time of the last update of the backend stage.
        """
        if created_at is not None:
            pulumi.set(__self__, "created_at", created_at)
        if lb_backend_configs is not None:
            pulumi.set(__self__, "lb_backend_configs", lb_backend_configs)
        if pipeline_id is not None:
            pulumi.set(__self__, "pipeline_id", pipeline_id)
        if project_id is not None:
            pulumi.set(__self__, "project_id", project_id)
        if s3_backend_config is not None:
            pulumi.set(__self__, "s3_backend_config", s3_backend_config)
        if updated_at is not None:
            pulumi.set(__self__, "updated_at", updated_at)

    @_builtins.property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The date and time of the creation of the backend stage.
        """
        return pulumi.get(self, "created_at")

    @created_at.setter
    def created_at(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "created_at", value)

    @_builtins.property
    @pulumi.getter(name="lbBackendConfigs")
    def lb_backend_configs(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['EdgeServicesBackendStageLbBackendConfigArgs']]]]:
        """
        The Scaleway Load Balancer linked to the backend stage.
        """
        return pulumi.get(self, "lb_backend_configs")

    @lb_backend_configs.setter
    def lb_backend_configs(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['EdgeServicesBackendStageLbBackendConfigArgs']]]]):
        pulumi.set(self, "lb_backend_configs", value)

    @_builtins.property
    @pulumi.getter(name="pipelineId")
    def pipeline_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The ID of the pipeline.
        """
        return pulumi.get(self, "pipeline_id")

    @pipeline_id.setter
    def pipeline_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "pipeline_id", value)

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        `project_id`) The ID of the project the backend stage is associated with.
        """
        return pulumi.get(self, "project_id")

    @project_id.setter
    def project_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "project_id", value)

    @_builtins.property
    @pulumi.getter(name="s3BackendConfig")
    def s3_backend_config(self) -> Optional[pulumi.Input['EdgeServicesBackendStageS3BackendConfigArgs']]:
        """
        The Scaleway Object Storage origin bucket (S3) linked to the backend stage.
        """
        return pulumi.get(self, "s3_backend_config")

    @s3_backend_config.setter
    def s3_backend_config(self, value: Optional[pulumi.Input['EdgeServicesBackendStageS3BackendConfigArgs']]):
        pulumi.set(self, "s3_backend_config", value)

    @_builtins.property
    @pulumi.getter(name="updatedAt")
    def updated_at(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The date and time of the last update of the backend stage.
        """
        return pulumi.get(self, "updated_at")

    @updated_at.setter
    def updated_at(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "updated_at", value)


warnings.warn("""scaleway.index/edgeservicesbackendstage.EdgeServicesBackendStage has been deprecated in favor of scaleway.edgeservices/backendstage.BackendStage""", DeprecationWarning)


@pulumi.type_token("scaleway:index/edgeServicesBackendStage:EdgeServicesBackendStage")
class EdgeServicesBackendStage(pulumi.CustomResource):
    warnings.warn("""scaleway.index/edgeservicesbackendstage.EdgeServicesBackendStage has been deprecated in favor of scaleway.edgeservices/backendstage.BackendStage""", DeprecationWarning)

    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 lb_backend_configs: Optional[pulumi.Input[Sequence[pulumi.Input[Union['EdgeServicesBackendStageLbBackendConfigArgs', 'EdgeServicesBackendStageLbBackendConfigArgsDict']]]]] = None,
                 pipeline_id: Optional[pulumi.Input[_builtins.str]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 s3_backend_config: Optional[pulumi.Input[Union['EdgeServicesBackendStageS3BackendConfigArgs', 'EdgeServicesBackendStageS3BackendConfigArgsDict']]] = None,
                 __props__=None):
        """
        Creates and manages Scaleway Edge Services Backend Stages.

        ## Example Usage

        ### With object backend

        ```python
        import pulumi
        import pulumiverse_scaleway as scaleway

        main = scaleway.object.Bucket("main",
            name="my-bucket-name",
            tags={
                "foo": "bar",
            })
        main_pipeline = scaleway.edgeservices.Pipeline("main", name="my-pipeline")
        main_backend_stage = scaleway.edgeservices.BackendStage("main",
            pipeline_id=main_pipeline.id,
            s3_backend_config={
                "bucket_name": main.name,
                "bucket_region": "fr-par",
            })
        ```

        ### With LB backend

        ```python
        import pulumi
        import pulumiverse_scaleway as scaleway

        main = scaleway.loadbalancers.LoadBalancer("main",
            ip_ids=[main_scaleway_lb_ip["id"]],
            zone="fr-par-1",
            type="LB-S")
        main_frontend = scaleway.loadbalancers.Frontend("main",
            lb_id=main.id,
            backend_id=main_scaleway_lb_backend["id"],
            name="frontend01",
            inbound_port=443,
            certificate_ids=[cert01["id"]])
        main_pipeline = scaleway.edgeservices.Pipeline("main", name="my-pipeline")
        main_backend_stage = scaleway.edgeservices.BackendStage("main",
            pipeline_id=main_pipeline.id,
            lb_backend_configs=[{
                "lb_config": {
                    "id": main.id,
                    "frontend_id": id,
                    "is_ssl": True,
                    "zone": "fr-par-1",
                },
            }])
        ```

        ## Import

        Backend stages can be imported using the `{id}`, e.g.

        bash

        ```sh
        $ pulumi import scaleway:index/edgeServicesBackendStage:EdgeServicesBackendStage basic 11111111-1111-1111-1111-111111111111
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Sequence[pulumi.Input[Union['EdgeServicesBackendStageLbBackendConfigArgs', 'EdgeServicesBackendStageLbBackendConfigArgsDict']]]] lb_backend_configs: The Scaleway Load Balancer linked to the backend stage.
        :param pulumi.Input[_builtins.str] pipeline_id: The ID of the pipeline.
        :param pulumi.Input[_builtins.str] project_id: `project_id`) The ID of the project the backend stage is associated with.
        :param pulumi.Input[Union['EdgeServicesBackendStageS3BackendConfigArgs', 'EdgeServicesBackendStageS3BackendConfigArgsDict']] s3_backend_config: The Scaleway Object Storage origin bucket (S3) linked to the backend stage.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: EdgeServicesBackendStageArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Creates and manages Scaleway Edge Services Backend Stages.

        ## Example Usage

        ### With object backend

        ```python
        import pulumi
        import pulumiverse_scaleway as scaleway

        main = scaleway.object.Bucket("main",
            name="my-bucket-name",
            tags={
                "foo": "bar",
            })
        main_pipeline = scaleway.edgeservices.Pipeline("main", name="my-pipeline")
        main_backend_stage = scaleway.edgeservices.BackendStage("main",
            pipeline_id=main_pipeline.id,
            s3_backend_config={
                "bucket_name": main.name,
                "bucket_region": "fr-par",
            })
        ```

        ### With LB backend

        ```python
        import pulumi
        import pulumiverse_scaleway as scaleway

        main = scaleway.loadbalancers.LoadBalancer("main",
            ip_ids=[main_scaleway_lb_ip["id"]],
            zone="fr-par-1",
            type="LB-S")
        main_frontend = scaleway.loadbalancers.Frontend("main",
            lb_id=main.id,
            backend_id=main_scaleway_lb_backend["id"],
            name="frontend01",
            inbound_port=443,
            certificate_ids=[cert01["id"]])
        main_pipeline = scaleway.edgeservices.Pipeline("main", name="my-pipeline")
        main_backend_stage = scaleway.edgeservices.BackendStage("main",
            pipeline_id=main_pipeline.id,
            lb_backend_configs=[{
                "lb_config": {
                    "id": main.id,
                    "frontend_id": id,
                    "is_ssl": True,
                    "zone": "fr-par-1",
                },
            }])
        ```

        ## Import

        Backend stages can be imported using the `{id}`, e.g.

        bash

        ```sh
        $ pulumi import scaleway:index/edgeServicesBackendStage:EdgeServicesBackendStage basic 11111111-1111-1111-1111-111111111111
        ```

        :param str resource_name: The name of the resource.
        :param EdgeServicesBackendStageArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(EdgeServicesBackendStageArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 lb_backend_configs: Optional[pulumi.Input[Sequence[pulumi.Input[Union['EdgeServicesBackendStageLbBackendConfigArgs', 'EdgeServicesBackendStageLbBackendConfigArgsDict']]]]] = None,
                 pipeline_id: Optional[pulumi.Input[_builtins.str]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 s3_backend_config: Optional[pulumi.Input[Union['EdgeServicesBackendStageS3BackendConfigArgs', 'EdgeServicesBackendStageS3BackendConfigArgsDict']]] = None,
                 __props__=None):
        pulumi.log.warn("""EdgeServicesBackendStage is deprecated: scaleway.index/edgeservicesbackendstage.EdgeServicesBackendStage has been deprecated in favor of scaleway.edgeservices/backendstage.BackendStage""")
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = EdgeServicesBackendStageArgs.__new__(EdgeServicesBackendStageArgs)

            __props__.__dict__["lb_backend_configs"] = lb_backend_configs
            if pipeline_id is None and not opts.urn:
                raise TypeError("Missing required property 'pipeline_id'")
            __props__.__dict__["pipeline_id"] = pipeline_id
            __props__.__dict__["project_id"] = project_id
            __props__.__dict__["s3_backend_config"] = s3_backend_config
            __props__.__dict__["created_at"] = None
            __props__.__dict__["updated_at"] = None
        super(EdgeServicesBackendStage, __self__).__init__(
            'scaleway:index/edgeServicesBackendStage:EdgeServicesBackendStage',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            created_at: Optional[pulumi.Input[_builtins.str]] = None,
            lb_backend_configs: Optional[pulumi.Input[Sequence[pulumi.Input[Union['EdgeServicesBackendStageLbBackendConfigArgs', 'EdgeServicesBackendStageLbBackendConfigArgsDict']]]]] = None,
            pipeline_id: Optional[pulumi.Input[_builtins.str]] = None,
            project_id: Optional[pulumi.Input[_builtins.str]] = None,
            s3_backend_config: Optional[pulumi.Input[Union['EdgeServicesBackendStageS3BackendConfigArgs', 'EdgeServicesBackendStageS3BackendConfigArgsDict']]] = None,
            updated_at: Optional[pulumi.Input[_builtins.str]] = None) -> 'EdgeServicesBackendStage':
        """
        Get an existing EdgeServicesBackendStage resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] created_at: The date and time of the creation of the backend stage.
        :param pulumi.Input[Sequence[pulumi.Input[Union['EdgeServicesBackendStageLbBackendConfigArgs', 'EdgeServicesBackendStageLbBackendConfigArgsDict']]]] lb_backend_configs: The Scaleway Load Balancer linked to the backend stage.
        :param pulumi.Input[_builtins.str] pipeline_id: The ID of the pipeline.
        :param pulumi.Input[_builtins.str] project_id: `project_id`) The ID of the project the backend stage is associated with.
        :param pulumi.Input[Union['EdgeServicesBackendStageS3BackendConfigArgs', 'EdgeServicesBackendStageS3BackendConfigArgsDict']] s3_backend_config: The Scaleway Object Storage origin bucket (S3) linked to the backend stage.
        :param pulumi.Input[_builtins.str] updated_at: The date and time of the last update of the backend stage.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _EdgeServicesBackendStageState.__new__(_EdgeServicesBackendStageState)

        __props__.__dict__["created_at"] = created_at
        __props__.__dict__["lb_backend_configs"] = lb_backend_configs
        __props__.__dict__["pipeline_id"] = pipeline_id
        __props__.__dict__["project_id"] = project_id
        __props__.__dict__["s3_backend_config"] = s3_backend_config
        __props__.__dict__["updated_at"] = updated_at
        return EdgeServicesBackendStage(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> pulumi.Output[_builtins.str]:
        """
        The date and time of the creation of the backend stage.
        """
        return pulumi.get(self, "created_at")

    @_builtins.property
    @pulumi.getter(name="lbBackendConfigs")
    def lb_backend_configs(self) -> pulumi.Output[Optional[Sequence['outputs.EdgeServicesBackendStageLbBackendConfig']]]:
        """
        The Scaleway Load Balancer linked to the backend stage.
        """
        return pulumi.get(self, "lb_backend_configs")

    @_builtins.property
    @pulumi.getter(name="pipelineId")
    def pipeline_id(self) -> pulumi.Output[_builtins.str]:
        """
        The ID of the pipeline.
        """
        return pulumi.get(self, "pipeline_id")

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> pulumi.Output[_builtins.str]:
        """
        `project_id`) The ID of the project the backend stage is associated with.
        """
        return pulumi.get(self, "project_id")

    @_builtins.property
    @pulumi.getter(name="s3BackendConfig")
    def s3_backend_config(self) -> pulumi.Output[Optional['outputs.EdgeServicesBackendStageS3BackendConfig']]:
        """
        The Scaleway Object Storage origin bucket (S3) linked to the backend stage.
        """
        return pulumi.get(self, "s3_backend_config")

    @_builtins.property
    @pulumi.getter(name="updatedAt")
    def updated_at(self) -> pulumi.Output[_builtins.str]:
        """
        The date and time of the last update of the backend stage.
        """
        return pulumi.get(self, "updated_at")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['ConnectionArgs', 'Connection']

@pulumi.input_type
class ConnectionArgs:
    def __init__(__self__, *,
                 bgp_config_ipv4s: Optional[pulumi.Input[Sequence[pulumi.Input['ConnectionBgpConfigIpv4Args']]]] = None,
                 bgp_config_ipv6s: Optional[pulumi.Input[Sequence[pulumi.Input['ConnectionBgpConfigIpv6Args']]]] = None,
                 customer_gateway_id: Optional[pulumi.Input[_builtins.str]] = None,
                 enable_route_propagation: Optional[pulumi.Input[_builtins.bool]] = None,
                 esp_ciphers: Optional[pulumi.Input[Sequence[pulumi.Input['ConnectionEspCipherArgs']]]] = None,
                 ikev2_ciphers: Optional[pulumi.Input[Sequence[pulumi.Input['ConnectionIkev2CipherArgs']]]] = None,
                 initiation_policy: Optional[pulumi.Input[_builtins.str]] = None,
                 is_ipv6: Optional[pulumi.Input[_builtins.bool]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 region: Optional[pulumi.Input[_builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 vpn_gateway_id: Optional[pulumi.Input[_builtins.str]] = None):
        """
        The set of arguments for constructing a Connection resource.
        :param pulumi.Input[Sequence[pulumi.Input['ConnectionBgpConfigIpv4Args']]] bgp_config_ipv4s: BGP configuration for IPv4. See BGP Config below.
        :param pulumi.Input[Sequence[pulumi.Input['ConnectionBgpConfigIpv6Args']]] bgp_config_ipv6s: BGP configuration for IPv6. See BGP Config below.
        :param pulumi.Input[_builtins.str] customer_gateway_id: The ID of the customer gateway to attach to the connection.
        :param pulumi.Input[_builtins.bool] enable_route_propagation: Defines whether route propagation is enabled or not.
        :param pulumi.Input[Sequence[pulumi.Input['ConnectionEspCipherArgs']]] esp_ciphers: ESP cipher configuration for Phase 2 (data encryption). See Cipher Config below.
        :param pulumi.Input[Sequence[pulumi.Input['ConnectionIkev2CipherArgs']]] ikev2_ciphers: IKEv2 cipher configuration for Phase 1 (tunnel establishment). See Cipher Config below.
        :param pulumi.Input[_builtins.str] initiation_policy: Defines who initiates the IPSec tunnel.
        :param pulumi.Input[_builtins.bool] is_ipv6: Defines IP version of the IPSec Tunnel. Defaults to `false` (IPv4).
        :param pulumi.Input[_builtins.str] name: The name of the connection.
        :param pulumi.Input[_builtins.str] project_id: `project_id`) The ID of the project the connection is associated with.
        :param pulumi.Input[_builtins.str] region: `region`) The region in which the connection should be created.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] tags: The list of tags to apply to the connection.
        :param pulumi.Input[_builtins.str] vpn_gateway_id: The ID of the VPN gateway to attach to the connection.
        """
        if bgp_config_ipv4s is not None:
            pulumi.set(__self__, "bgp_config_ipv4s", bgp_config_ipv4s)
        if bgp_config_ipv6s is not None:
            pulumi.set(__self__, "bgp_config_ipv6s", bgp_config_ipv6s)
        if customer_gateway_id is not None:
            pulumi.set(__self__, "customer_gateway_id", customer_gateway_id)
        if enable_route_propagation is not None:
            pulumi.set(__self__, "enable_route_propagation", enable_route_propagation)
        if esp_ciphers is not None:
            pulumi.set(__self__, "esp_ciphers", esp_ciphers)
        if ikev2_ciphers is not None:
            pulumi.set(__self__, "ikev2_ciphers", ikev2_ciphers)
        if initiation_policy is not None:
            pulumi.set(__self__, "initiation_policy", initiation_policy)
        if is_ipv6 is not None:
            pulumi.set(__self__, "is_ipv6", is_ipv6)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if project_id is not None:
            pulumi.set(__self__, "project_id", project_id)
        if region is not None:
            pulumi.set(__self__, "region", region)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)
        if vpn_gateway_id is not None:
            pulumi.set(__self__, "vpn_gateway_id", vpn_gateway_id)

    @_builtins.property
    @pulumi.getter(name="bgpConfigIpv4s")
    def bgp_config_ipv4s(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['ConnectionBgpConfigIpv4Args']]]]:
        """
        BGP configuration for IPv4. See BGP Config below.
        """
        return pulumi.get(self, "bgp_config_ipv4s")

    @bgp_config_ipv4s.setter
    def bgp_config_ipv4s(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['ConnectionBgpConfigIpv4Args']]]]):
        pulumi.set(self, "bgp_config_ipv4s", value)

    @_builtins.property
    @pulumi.getter(name="bgpConfigIpv6s")
    def bgp_config_ipv6s(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['ConnectionBgpConfigIpv6Args']]]]:
        """
        BGP configuration for IPv6. See BGP Config below.
        """
        return pulumi.get(self, "bgp_config_ipv6s")

    @bgp_config_ipv6s.setter
    def bgp_config_ipv6s(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['ConnectionBgpConfigIpv6Args']]]]):
        pulumi.set(self, "bgp_config_ipv6s", value)

    @_builtins.property
    @pulumi.getter(name="customerGatewayId")
    def customer_gateway_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The ID of the customer gateway to attach to the connection.
        """
        return pulumi.get(self, "customer_gateway_id")

    @customer_gateway_id.setter
    def customer_gateway_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "customer_gateway_id", value)

    @_builtins.property
    @pulumi.getter(name="enableRoutePropagation")
    def enable_route_propagation(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Defines whether route propagation is enabled or not.
        """
        return pulumi.get(self, "enable_route_propagation")

    @enable_route_propagation.setter
    def enable_route_propagation(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "enable_route_propagation", value)

    @_builtins.property
    @pulumi.getter(name="espCiphers")
    def esp_ciphers(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['ConnectionEspCipherArgs']]]]:
        """
        ESP cipher configuration for Phase 2 (data encryption). See Cipher Config below.
        """
        return pulumi.get(self, "esp_ciphers")

    @esp_ciphers.setter
    def esp_ciphers(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['ConnectionEspCipherArgs']]]]):
        pulumi.set(self, "esp_ciphers", value)

    @_builtins.property
    @pulumi.getter(name="ikev2Ciphers")
    def ikev2_ciphers(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['ConnectionIkev2CipherArgs']]]]:
        """
        IKEv2 cipher configuration for Phase 1 (tunnel establishment). See Cipher Config below.
        """
        return pulumi.get(self, "ikev2_ciphers")

    @ikev2_ciphers.setter
    def ikev2_ciphers(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['ConnectionIkev2CipherArgs']]]]):
        pulumi.set(self, "ikev2_ciphers", value)

    @_builtins.property
    @pulumi.getter(name="initiationPolicy")
    def initiation_policy(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Defines who initiates the IPSec tunnel.
        """
        return pulumi.get(self, "initiation_policy")

    @initiation_policy.setter
    def initiation_policy(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "initiation_policy", value)

    @_builtins.property
    @pulumi.getter(name="isIpv6")
    def is_ipv6(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Defines IP version of the IPSec Tunnel. Defaults to `false` (IPv4).
        """
        return pulumi.get(self, "is_ipv6")

    @is_ipv6.setter
    def is_ipv6(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "is_ipv6", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The name of the connection.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        `project_id`) The ID of the project the connection is associated with.
        """
        return pulumi.get(self, "project_id")

    @project_id.setter
    def project_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "project_id", value)

    @_builtins.property
    @pulumi.getter
    def region(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        `region`) The region in which the connection should be created.
        """
        return pulumi.get(self, "region")

    @region.setter
    def region(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "region", value)

    @_builtins.property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        The list of tags to apply to the connection.
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "tags", value)

    @_builtins.property
    @pulumi.getter(name="vpnGatewayId")
    def vpn_gateway_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The ID of the VPN gateway to attach to the connection.
        """
        return pulumi.get(self, "vpn_gateway_id")

    @vpn_gateway_id.setter
    def vpn_gateway_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "vpn_gateway_id", value)


@pulumi.input_type
class _ConnectionState:
    def __init__(__self__, *,
                 bgp_config_ipv4s: Optional[pulumi.Input[Sequence[pulumi.Input['ConnectionBgpConfigIpv4Args']]]] = None,
                 bgp_config_ipv6s: Optional[pulumi.Input[Sequence[pulumi.Input['ConnectionBgpConfigIpv6Args']]]] = None,
                 bgp_session_ipv4s: Optional[pulumi.Input[Sequence[pulumi.Input['ConnectionBgpSessionIpv4Args']]]] = None,
                 bgp_session_ipv6s: Optional[pulumi.Input[Sequence[pulumi.Input['ConnectionBgpSessionIpv6Args']]]] = None,
                 bgp_status_ipv4: Optional[pulumi.Input[_builtins.str]] = None,
                 bgp_status_ipv6: Optional[pulumi.Input[_builtins.str]] = None,
                 created_at: Optional[pulumi.Input[_builtins.str]] = None,
                 customer_gateway_id: Optional[pulumi.Input[_builtins.str]] = None,
                 enable_route_propagation: Optional[pulumi.Input[_builtins.bool]] = None,
                 esp_ciphers: Optional[pulumi.Input[Sequence[pulumi.Input['ConnectionEspCipherArgs']]]] = None,
                 ikev2_ciphers: Optional[pulumi.Input[Sequence[pulumi.Input['ConnectionIkev2CipherArgs']]]] = None,
                 initiation_policy: Optional[pulumi.Input[_builtins.str]] = None,
                 is_ipv6: Optional[pulumi.Input[_builtins.bool]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 organization_id: Optional[pulumi.Input[_builtins.str]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 region: Optional[pulumi.Input[_builtins.str]] = None,
                 route_propagation_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 secret_id: Optional[pulumi.Input[_builtins.str]] = None,
                 secret_version: Optional[pulumi.Input[_builtins.int]] = None,
                 status: Optional[pulumi.Input[_builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 tunnel_status: Optional[pulumi.Input[_builtins.str]] = None,
                 updated_at: Optional[pulumi.Input[_builtins.str]] = None,
                 vpn_gateway_id: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering Connection resources.
        :param pulumi.Input[Sequence[pulumi.Input['ConnectionBgpConfigIpv4Args']]] bgp_config_ipv4s: BGP configuration for IPv4. See BGP Config below.
        :param pulumi.Input[Sequence[pulumi.Input['ConnectionBgpConfigIpv6Args']]] bgp_config_ipv6s: BGP configuration for IPv6. See BGP Config below.
        :param pulumi.Input[Sequence[pulumi.Input['ConnectionBgpSessionIpv4Args']]] bgp_session_ipv4s: The BGP IPv4 session information. See BGP Session below.
        :param pulumi.Input[Sequence[pulumi.Input['ConnectionBgpSessionIpv6Args']]] bgp_session_ipv6s: The BGP IPv6 session information. See BGP Session below.
        :param pulumi.Input[_builtins.str] bgp_status_ipv4: The status of the BGP IPv4 session.
        :param pulumi.Input[_builtins.str] bgp_status_ipv6: The status of the BGP IPv6 session.
        :param pulumi.Input[_builtins.str] created_at: The date and time of the creation of the connection (RFC 3339 format).
        :param pulumi.Input[_builtins.str] customer_gateway_id: The ID of the customer gateway to attach to the connection.
        :param pulumi.Input[_builtins.bool] enable_route_propagation: Defines whether route propagation is enabled or not.
        :param pulumi.Input[Sequence[pulumi.Input['ConnectionEspCipherArgs']]] esp_ciphers: ESP cipher configuration for Phase 2 (data encryption). See Cipher Config below.
        :param pulumi.Input[Sequence[pulumi.Input['ConnectionIkev2CipherArgs']]] ikev2_ciphers: IKEv2 cipher configuration for Phase 1 (tunnel establishment). See Cipher Config below.
        :param pulumi.Input[_builtins.str] initiation_policy: Defines who initiates the IPSec tunnel.
        :param pulumi.Input[_builtins.bool] is_ipv6: Defines IP version of the IPSec Tunnel. Defaults to `false` (IPv4).
        :param pulumi.Input[_builtins.str] name: The name of the connection.
        :param pulumi.Input[_builtins.str] organization_id: The Organization ID the connection is associated with.
        :param pulumi.Input[_builtins.str] project_id: `project_id`) The ID of the project the connection is associated with.
        :param pulumi.Input[_builtins.str] region: `region`) The region in which the connection should be created.
        :param pulumi.Input[_builtins.bool] route_propagation_enabled: Whether route propagation is enabled.
        :param pulumi.Input[_builtins.str] secret_id: The ID of the secret containing the pre-shared key (PSK) for the connection.
        :param pulumi.Input[_builtins.int] secret_version: The version of the secret containing the PSK.
        :param pulumi.Input[_builtins.str] status: The status of the connection.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] tags: The list of tags to apply to the connection.
        :param pulumi.Input[_builtins.str] tunnel_status: The status of the IPSec tunnel.
        :param pulumi.Input[_builtins.str] updated_at: The date and time of the last update of the connection (RFC 3339 format).
        :param pulumi.Input[_builtins.str] vpn_gateway_id: The ID of the VPN gateway to attach to the connection.
        """
        if bgp_config_ipv4s is not None:
            pulumi.set(__self__, "bgp_config_ipv4s", bgp_config_ipv4s)
        if bgp_config_ipv6s is not None:
            pulumi.set(__self__, "bgp_config_ipv6s", bgp_config_ipv6s)
        if bgp_session_ipv4s is not None:
            pulumi.set(__self__, "bgp_session_ipv4s", bgp_session_ipv4s)
        if bgp_session_ipv6s is not None:
            pulumi.set(__self__, "bgp_session_ipv6s", bgp_session_ipv6s)
        if bgp_status_ipv4 is not None:
            pulumi.set(__self__, "bgp_status_ipv4", bgp_status_ipv4)
        if bgp_status_ipv6 is not None:
            pulumi.set(__self__, "bgp_status_ipv6", bgp_status_ipv6)
        if created_at is not None:
            pulumi.set(__self__, "created_at", created_at)
        if customer_gateway_id is not None:
            pulumi.set(__self__, "customer_gateway_id", customer_gateway_id)
        if enable_route_propagation is not None:
            pulumi.set(__self__, "enable_route_propagation", enable_route_propagation)
        if esp_ciphers is not None:
            pulumi.set(__self__, "esp_ciphers", esp_ciphers)
        if ikev2_ciphers is not None:
            pulumi.set(__self__, "ikev2_ciphers", ikev2_ciphers)
        if initiation_policy is not None:
            pulumi.set(__self__, "initiation_policy", initiation_policy)
        if is_ipv6 is not None:
            pulumi.set(__self__, "is_ipv6", is_ipv6)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if organization_id is not None:
            pulumi.set(__self__, "organization_id", organization_id)
        if project_id is not None:
            pulumi.set(__self__, "project_id", project_id)
        if region is not None:
            pulumi.set(__self__, "region", region)
        if route_propagation_enabled is not None:
            pulumi.set(__self__, "route_propagation_enabled", route_propagation_enabled)
        if secret_id is not None:
            pulumi.set(__self__, "secret_id", secret_id)
        if secret_version is not None:
            pulumi.set(__self__, "secret_version", secret_version)
        if status is not None:
            pulumi.set(__self__, "status", status)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)
        if tunnel_status is not None:
            pulumi.set(__self__, "tunnel_status", tunnel_status)
        if updated_at is not None:
            pulumi.set(__self__, "updated_at", updated_at)
        if vpn_gateway_id is not None:
            pulumi.set(__self__, "vpn_gateway_id", vpn_gateway_id)

    @_builtins.property
    @pulumi.getter(name="bgpConfigIpv4s")
    def bgp_config_ipv4s(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['ConnectionBgpConfigIpv4Args']]]]:
        """
        BGP configuration for IPv4. See BGP Config below.
        """
        return pulumi.get(self, "bgp_config_ipv4s")

    @bgp_config_ipv4s.setter
    def bgp_config_ipv4s(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['ConnectionBgpConfigIpv4Args']]]]):
        pulumi.set(self, "bgp_config_ipv4s", value)

    @_builtins.property
    @pulumi.getter(name="bgpConfigIpv6s")
    def bgp_config_ipv6s(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['ConnectionBgpConfigIpv6Args']]]]:
        """
        BGP configuration for IPv6. See BGP Config below.
        """
        return pulumi.get(self, "bgp_config_ipv6s")

    @bgp_config_ipv6s.setter
    def bgp_config_ipv6s(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['ConnectionBgpConfigIpv6Args']]]]):
        pulumi.set(self, "bgp_config_ipv6s", value)

    @_builtins.property
    @pulumi.getter(name="bgpSessionIpv4s")
    def bgp_session_ipv4s(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['ConnectionBgpSessionIpv4Args']]]]:
        """
        The BGP IPv4 session information. See BGP Session below.
        """
        return pulumi.get(self, "bgp_session_ipv4s")

    @bgp_session_ipv4s.setter
    def bgp_session_ipv4s(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['ConnectionBgpSessionIpv4Args']]]]):
        pulumi.set(self, "bgp_session_ipv4s", value)

    @_builtins.property
    @pulumi.getter(name="bgpSessionIpv6s")
    def bgp_session_ipv6s(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['ConnectionBgpSessionIpv6Args']]]]:
        """
        The BGP IPv6 session information. See BGP Session below.
        """
        return pulumi.get(self, "bgp_session_ipv6s")

    @bgp_session_ipv6s.setter
    def bgp_session_ipv6s(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['ConnectionBgpSessionIpv6Args']]]]):
        pulumi.set(self, "bgp_session_ipv6s", value)

    @_builtins.property
    @pulumi.getter(name="bgpStatusIpv4")
    def bgp_status_ipv4(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The status of the BGP IPv4 session.
        """
        return pulumi.get(self, "bgp_status_ipv4")

    @bgp_status_ipv4.setter
    def bgp_status_ipv4(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "bgp_status_ipv4", value)

    @_builtins.property
    @pulumi.getter(name="bgpStatusIpv6")
    def bgp_status_ipv6(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The status of the BGP IPv6 session.
        """
        return pulumi.get(self, "bgp_status_ipv6")

    @bgp_status_ipv6.setter
    def bgp_status_ipv6(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "bgp_status_ipv6", value)

    @_builtins.property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The date and time of the creation of the connection (RFC 3339 format).
        """
        return pulumi.get(self, "created_at")

    @created_at.setter
    def created_at(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "created_at", value)

    @_builtins.property
    @pulumi.getter(name="customerGatewayId")
    def customer_gateway_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The ID of the customer gateway to attach to the connection.
        """
        return pulumi.get(self, "customer_gateway_id")

    @customer_gateway_id.setter
    def customer_gateway_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "customer_gateway_id", value)

    @_builtins.property
    @pulumi.getter(name="enableRoutePropagation")
    def enable_route_propagation(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Defines whether route propagation is enabled or not.
        """
        return pulumi.get(self, "enable_route_propagation")

    @enable_route_propagation.setter
    def enable_route_propagation(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "enable_route_propagation", value)

    @_builtins.property
    @pulumi.getter(name="espCiphers")
    def esp_ciphers(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['ConnectionEspCipherArgs']]]]:
        """
        ESP cipher configuration for Phase 2 (data encryption). See Cipher Config below.
        """
        return pulumi.get(self, "esp_ciphers")

    @esp_ciphers.setter
    def esp_ciphers(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['ConnectionEspCipherArgs']]]]):
        pulumi.set(self, "esp_ciphers", value)

    @_builtins.property
    @pulumi.getter(name="ikev2Ciphers")
    def ikev2_ciphers(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['ConnectionIkev2CipherArgs']]]]:
        """
        IKEv2 cipher configuration for Phase 1 (tunnel establishment). See Cipher Config below.
        """
        return pulumi.get(self, "ikev2_ciphers")

    @ikev2_ciphers.setter
    def ikev2_ciphers(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['ConnectionIkev2CipherArgs']]]]):
        pulumi.set(self, "ikev2_ciphers", value)

    @_builtins.property
    @pulumi.getter(name="initiationPolicy")
    def initiation_policy(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Defines who initiates the IPSec tunnel.
        """
        return pulumi.get(self, "initiation_policy")

    @initiation_policy.setter
    def initiation_policy(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "initiation_policy", value)

    @_builtins.property
    @pulumi.getter(name="isIpv6")
    def is_ipv6(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Defines IP version of the IPSec Tunnel. Defaults to `false` (IPv4).
        """
        return pulumi.get(self, "is_ipv6")

    @is_ipv6.setter
    def is_ipv6(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "is_ipv6", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The name of the connection.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter(name="organizationId")
    def organization_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The Organization ID the connection is associated with.
        """
        return pulumi.get(self, "organization_id")

    @organization_id.setter
    def organization_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "organization_id", value)

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        `project_id`) The ID of the project the connection is associated with.
        """
        return pulumi.get(self, "project_id")

    @project_id.setter
    def project_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "project_id", value)

    @_builtins.property
    @pulumi.getter
    def region(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        `region`) The region in which the connection should be created.
        """
        return pulumi.get(self, "region")

    @region.setter
    def region(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "region", value)

    @_builtins.property
    @pulumi.getter(name="routePropagationEnabled")
    def route_propagation_enabled(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Whether route propagation is enabled.
        """
        return pulumi.get(self, "route_propagation_enabled")

    @route_propagation_enabled.setter
    def route_propagation_enabled(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "route_propagation_enabled", value)

    @_builtins.property
    @pulumi.getter(name="secretId")
    def secret_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The ID of the secret containing the pre-shared key (PSK) for the connection.
        """
        return pulumi.get(self, "secret_id")

    @secret_id.setter
    def secret_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "secret_id", value)

    @_builtins.property
    @pulumi.getter(name="secretVersion")
    def secret_version(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        The version of the secret containing the PSK.
        """
        return pulumi.get(self, "secret_version")

    @secret_version.setter
    def secret_version(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "secret_version", value)

    @_builtins.property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The status of the connection.
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "status", value)

    @_builtins.property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        The list of tags to apply to the connection.
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "tags", value)

    @_builtins.property
    @pulumi.getter(name="tunnelStatus")
    def tunnel_status(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The status of the IPSec tunnel.
        """
        return pulumi.get(self, "tunnel_status")

    @tunnel_status.setter
    def tunnel_status(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "tunnel_status", value)

    @_builtins.property
    @pulumi.getter(name="updatedAt")
    def updated_at(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The date and time of the last update of the connection (RFC 3339 format).
        """
        return pulumi.get(self, "updated_at")

    @updated_at.setter
    def updated_at(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "updated_at", value)

    @_builtins.property
    @pulumi.getter(name="vpnGatewayId")
    def vpn_gateway_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The ID of the VPN gateway to attach to the connection.
        """
        return pulumi.get(self, "vpn_gateway_id")

    @vpn_gateway_id.setter
    def vpn_gateway_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "vpn_gateway_id", value)


@pulumi.type_token("scaleway:s2svpn/connection:Connection")
class Connection(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 bgp_config_ipv4s: Optional[pulumi.Input[Sequence[pulumi.Input[Union['ConnectionBgpConfigIpv4Args', 'ConnectionBgpConfigIpv4ArgsDict']]]]] = None,
                 bgp_config_ipv6s: Optional[pulumi.Input[Sequence[pulumi.Input[Union['ConnectionBgpConfigIpv6Args', 'ConnectionBgpConfigIpv6ArgsDict']]]]] = None,
                 customer_gateway_id: Optional[pulumi.Input[_builtins.str]] = None,
                 enable_route_propagation: Optional[pulumi.Input[_builtins.bool]] = None,
                 esp_ciphers: Optional[pulumi.Input[Sequence[pulumi.Input[Union['ConnectionEspCipherArgs', 'ConnectionEspCipherArgsDict']]]]] = None,
                 ikev2_ciphers: Optional[pulumi.Input[Sequence[pulumi.Input[Union['ConnectionIkev2CipherArgs', 'ConnectionIkev2CipherArgsDict']]]]] = None,
                 initiation_policy: Optional[pulumi.Input[_builtins.str]] = None,
                 is_ipv6: Optional[pulumi.Input[_builtins.bool]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 region: Optional[pulumi.Input[_builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 vpn_gateway_id: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        Creates and manages Scaleway Site-to-Site VPN Connections.
        A connection links a Scaleway VPN Gateway to a Customer Gateway and establishes an IPSec tunnel with BGP routing.

        For more information, see [the main documentation](https://www.scaleway.com/en/docs/site-to-site-vpn/reference-content/understanding-s2svpn/).

        ## Example Usage

        ### Basic Connection

        ```python
        import pulumi
        import pulumiverse_scaleway as scaleway

        vpc = scaleway.network.Vpc("vpc", name="my-vpc")
        pn = scaleway.network.PrivateNetwork("pn",
            name="my-private-network",
            vpc_id=vpc.id,
            ipv4_subnet={
                "subnet": "10.0.1.0/24",
            })
        gateway = scaleway.s2svpn.Gateway("gateway",
            name="my-vpn-gateway",
            gateway_type="VGW-S",
            private_network_id=pn.id)
        customer_gw = scaleway.s2svpn.CustomerGateway("customer_gw",
            name="my-customer-gateway",
            ipv4_public="203.0.113.1",
            asn=65000)
        policy = scaleway.s2svpn.RoutingPolicy("policy",
            name="my-routing-policy",
            prefix_filter_ins=["10.0.2.0/24"],
            prefix_filter_outs=["10.0.1.0/24"])
        main = scaleway.s2svpn.Connection("main",
            name="my-vpn-connection",
            vpn_gateway_id=gateway.id,
            customer_gateway_id=customer_gw.id,
            initiation_policy="customer_gateway",
            enable_route_propagation=True,
            bgp_config_ipv4s=[{
                "routing_policy_id": policy.id,
                "private_ip": "169.254.0.1/30",
                "peer_private_ip": "169.254.0.2/30",
            }],
            ikev2_ciphers=[{
                "encryption": "aes256",
                "integrity": "sha256",
                "dh_group": "modp2048",
            }],
            esp_ciphers=[{
                "encryption": "aes256",
                "integrity": "sha256",
                "dh_group": "modp2048",
            }])
        ```

        ## Import

        Connections can be imported using `{region}/{id}`, e.g.

        bash

        ```sh
        $ pulumi import scaleway:s2svpn/connection:Connection main fr-par/11111111-1111-1111-1111-111111111111
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Sequence[pulumi.Input[Union['ConnectionBgpConfigIpv4Args', 'ConnectionBgpConfigIpv4ArgsDict']]]] bgp_config_ipv4s: BGP configuration for IPv4. See BGP Config below.
        :param pulumi.Input[Sequence[pulumi.Input[Union['ConnectionBgpConfigIpv6Args', 'ConnectionBgpConfigIpv6ArgsDict']]]] bgp_config_ipv6s: BGP configuration for IPv6. See BGP Config below.
        :param pulumi.Input[_builtins.str] customer_gateway_id: The ID of the customer gateway to attach to the connection.
        :param pulumi.Input[_builtins.bool] enable_route_propagation: Defines whether route propagation is enabled or not.
        :param pulumi.Input[Sequence[pulumi.Input[Union['ConnectionEspCipherArgs', 'ConnectionEspCipherArgsDict']]]] esp_ciphers: ESP cipher configuration for Phase 2 (data encryption). See Cipher Config below.
        :param pulumi.Input[Sequence[pulumi.Input[Union['ConnectionIkev2CipherArgs', 'ConnectionIkev2CipherArgsDict']]]] ikev2_ciphers: IKEv2 cipher configuration for Phase 1 (tunnel establishment). See Cipher Config below.
        :param pulumi.Input[_builtins.str] initiation_policy: Defines who initiates the IPSec tunnel.
        :param pulumi.Input[_builtins.bool] is_ipv6: Defines IP version of the IPSec Tunnel. Defaults to `false` (IPv4).
        :param pulumi.Input[_builtins.str] name: The name of the connection.
        :param pulumi.Input[_builtins.str] project_id: `project_id`) The ID of the project the connection is associated with.
        :param pulumi.Input[_builtins.str] region: `region`) The region in which the connection should be created.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] tags: The list of tags to apply to the connection.
        :param pulumi.Input[_builtins.str] vpn_gateway_id: The ID of the VPN gateway to attach to the connection.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: Optional[ConnectionArgs] = None,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Creates and manages Scaleway Site-to-Site VPN Connections.
        A connection links a Scaleway VPN Gateway to a Customer Gateway and establishes an IPSec tunnel with BGP routing.

        For more information, see [the main documentation](https://www.scaleway.com/en/docs/site-to-site-vpn/reference-content/understanding-s2svpn/).

        ## Example Usage

        ### Basic Connection

        ```python
        import pulumi
        import pulumiverse_scaleway as scaleway

        vpc = scaleway.network.Vpc("vpc", name="my-vpc")
        pn = scaleway.network.PrivateNetwork("pn",
            name="my-private-network",
            vpc_id=vpc.id,
            ipv4_subnet={
                "subnet": "10.0.1.0/24",
            })
        gateway = scaleway.s2svpn.Gateway("gateway",
            name="my-vpn-gateway",
            gateway_type="VGW-S",
            private_network_id=pn.id)
        customer_gw = scaleway.s2svpn.CustomerGateway("customer_gw",
            name="my-customer-gateway",
            ipv4_public="203.0.113.1",
            asn=65000)
        policy = scaleway.s2svpn.RoutingPolicy("policy",
            name="my-routing-policy",
            prefix_filter_ins=["10.0.2.0/24"],
            prefix_filter_outs=["10.0.1.0/24"])
        main = scaleway.s2svpn.Connection("main",
            name="my-vpn-connection",
            vpn_gateway_id=gateway.id,
            customer_gateway_id=customer_gw.id,
            initiation_policy="customer_gateway",
            enable_route_propagation=True,
            bgp_config_ipv4s=[{
                "routing_policy_id": policy.id,
                "private_ip": "169.254.0.1/30",
                "peer_private_ip": "169.254.0.2/30",
            }],
            ikev2_ciphers=[{
                "encryption": "aes256",
                "integrity": "sha256",
                "dh_group": "modp2048",
            }],
            esp_ciphers=[{
                "encryption": "aes256",
                "integrity": "sha256",
                "dh_group": "modp2048",
            }])
        ```

        ## Import

        Connections can be imported using `{region}/{id}`, e.g.

        bash

        ```sh
        $ pulumi import scaleway:s2svpn/connection:Connection main fr-par/11111111-1111-1111-1111-111111111111
        ```

        :param str resource_name: The name of the resource.
        :param ConnectionArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(ConnectionArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 bgp_config_ipv4s: Optional[pulumi.Input[Sequence[pulumi.Input[Union['ConnectionBgpConfigIpv4Args', 'ConnectionBgpConfigIpv4ArgsDict']]]]] = None,
                 bgp_config_ipv6s: Optional[pulumi.Input[Sequence[pulumi.Input[Union['ConnectionBgpConfigIpv6Args', 'ConnectionBgpConfigIpv6ArgsDict']]]]] = None,
                 customer_gateway_id: Optional[pulumi.Input[_builtins.str]] = None,
                 enable_route_propagation: Optional[pulumi.Input[_builtins.bool]] = None,
                 esp_ciphers: Optional[pulumi.Input[Sequence[pulumi.Input[Union['ConnectionEspCipherArgs', 'ConnectionEspCipherArgsDict']]]]] = None,
                 ikev2_ciphers: Optional[pulumi.Input[Sequence[pulumi.Input[Union['ConnectionIkev2CipherArgs', 'ConnectionIkev2CipherArgsDict']]]]] = None,
                 initiation_policy: Optional[pulumi.Input[_builtins.str]] = None,
                 is_ipv6: Optional[pulumi.Input[_builtins.bool]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 region: Optional[pulumi.Input[_builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 vpn_gateway_id: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = ConnectionArgs.__new__(ConnectionArgs)

            __props__.__dict__["bgp_config_ipv4s"] = bgp_config_ipv4s
            __props__.__dict__["bgp_config_ipv6s"] = bgp_config_ipv6s
            __props__.__dict__["customer_gateway_id"] = customer_gateway_id
            __props__.__dict__["enable_route_propagation"] = enable_route_propagation
            __props__.__dict__["esp_ciphers"] = esp_ciphers
            __props__.__dict__["ikev2_ciphers"] = ikev2_ciphers
            __props__.__dict__["initiation_policy"] = initiation_policy
            __props__.__dict__["is_ipv6"] = is_ipv6
            __props__.__dict__["name"] = name
            __props__.__dict__["project_id"] = project_id
            __props__.__dict__["region"] = region
            __props__.__dict__["tags"] = tags
            __props__.__dict__["vpn_gateway_id"] = vpn_gateway_id
            __props__.__dict__["bgp_session_ipv4s"] = None
            __props__.__dict__["bgp_session_ipv6s"] = None
            __props__.__dict__["bgp_status_ipv4"] = None
            __props__.__dict__["bgp_status_ipv6"] = None
            __props__.__dict__["created_at"] = None
            __props__.__dict__["organization_id"] = None
            __props__.__dict__["route_propagation_enabled"] = None
            __props__.__dict__["secret_id"] = None
            __props__.__dict__["secret_version"] = None
            __props__.__dict__["status"] = None
            __props__.__dict__["tunnel_status"] = None
            __props__.__dict__["updated_at"] = None
        super(Connection, __self__).__init__(
            'scaleway:s2svpn/connection:Connection',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            bgp_config_ipv4s: Optional[pulumi.Input[Sequence[pulumi.Input[Union['ConnectionBgpConfigIpv4Args', 'ConnectionBgpConfigIpv4ArgsDict']]]]] = None,
            bgp_config_ipv6s: Optional[pulumi.Input[Sequence[pulumi.Input[Union['ConnectionBgpConfigIpv6Args', 'ConnectionBgpConfigIpv6ArgsDict']]]]] = None,
            bgp_session_ipv4s: Optional[pulumi.Input[Sequence[pulumi.Input[Union['ConnectionBgpSessionIpv4Args', 'ConnectionBgpSessionIpv4ArgsDict']]]]] = None,
            bgp_session_ipv6s: Optional[pulumi.Input[Sequence[pulumi.Input[Union['ConnectionBgpSessionIpv6Args', 'ConnectionBgpSessionIpv6ArgsDict']]]]] = None,
            bgp_status_ipv4: Optional[pulumi.Input[_builtins.str]] = None,
            bgp_status_ipv6: Optional[pulumi.Input[_builtins.str]] = None,
            created_at: Optional[pulumi.Input[_builtins.str]] = None,
            customer_gateway_id: Optional[pulumi.Input[_builtins.str]] = None,
            enable_route_propagation: Optional[pulumi.Input[_builtins.bool]] = None,
            esp_ciphers: Optional[pulumi.Input[Sequence[pulumi.Input[Union['ConnectionEspCipherArgs', 'ConnectionEspCipherArgsDict']]]]] = None,
            ikev2_ciphers: Optional[pulumi.Input[Sequence[pulumi.Input[Union['ConnectionIkev2CipherArgs', 'ConnectionIkev2CipherArgsDict']]]]] = None,
            initiation_policy: Optional[pulumi.Input[_builtins.str]] = None,
            is_ipv6: Optional[pulumi.Input[_builtins.bool]] = None,
            name: Optional[pulumi.Input[_builtins.str]] = None,
            organization_id: Optional[pulumi.Input[_builtins.str]] = None,
            project_id: Optional[pulumi.Input[_builtins.str]] = None,
            region: Optional[pulumi.Input[_builtins.str]] = None,
            route_propagation_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
            secret_id: Optional[pulumi.Input[_builtins.str]] = None,
            secret_version: Optional[pulumi.Input[_builtins.int]] = None,
            status: Optional[pulumi.Input[_builtins.str]] = None,
            tags: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
            tunnel_status: Optional[pulumi.Input[_builtins.str]] = None,
            updated_at: Optional[pulumi.Input[_builtins.str]] = None,
            vpn_gateway_id: Optional[pulumi.Input[_builtins.str]] = None) -> 'Connection':
        """
        Get an existing Connection resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Sequence[pulumi.Input[Union['ConnectionBgpConfigIpv4Args', 'ConnectionBgpConfigIpv4ArgsDict']]]] bgp_config_ipv4s: BGP configuration for IPv4. See BGP Config below.
        :param pulumi.Input[Sequence[pulumi.Input[Union['ConnectionBgpConfigIpv6Args', 'ConnectionBgpConfigIpv6ArgsDict']]]] bgp_config_ipv6s: BGP configuration for IPv6. See BGP Config below.
        :param pulumi.Input[Sequence[pulumi.Input[Union['ConnectionBgpSessionIpv4Args', 'ConnectionBgpSessionIpv4ArgsDict']]]] bgp_session_ipv4s: The BGP IPv4 session information. See BGP Session below.
        :param pulumi.Input[Sequence[pulumi.Input[Union['ConnectionBgpSessionIpv6Args', 'ConnectionBgpSessionIpv6ArgsDict']]]] bgp_session_ipv6s: The BGP IPv6 session information. See BGP Session below.
        :param pulumi.Input[_builtins.str] bgp_status_ipv4: The status of the BGP IPv4 session.
        :param pulumi.Input[_builtins.str] bgp_status_ipv6: The status of the BGP IPv6 session.
        :param pulumi.Input[_builtins.str] created_at: The date and time of the creation of the connection (RFC 3339 format).
        :param pulumi.Input[_builtins.str] customer_gateway_id: The ID of the customer gateway to attach to the connection.
        :param pulumi.Input[_builtins.bool] enable_route_propagation: Defines whether route propagation is enabled or not.
        :param pulumi.Input[Sequence[pulumi.Input[Union['ConnectionEspCipherArgs', 'ConnectionEspCipherArgsDict']]]] esp_ciphers: ESP cipher configuration for Phase 2 (data encryption). See Cipher Config below.
        :param pulumi.Input[Sequence[pulumi.Input[Union['ConnectionIkev2CipherArgs', 'ConnectionIkev2CipherArgsDict']]]] ikev2_ciphers: IKEv2 cipher configuration for Phase 1 (tunnel establishment). See Cipher Config below.
        :param pulumi.Input[_builtins.str] initiation_policy: Defines who initiates the IPSec tunnel.
        :param pulumi.Input[_builtins.bool] is_ipv6: Defines IP version of the IPSec Tunnel. Defaults to `false` (IPv4).
        :param pulumi.Input[_builtins.str] name: The name of the connection.
        :param pulumi.Input[_builtins.str] organization_id: The Organization ID the connection is associated with.
        :param pulumi.Input[_builtins.str] project_id: `project_id`) The ID of the project the connection is associated with.
        :param pulumi.Input[_builtins.str] region: `region`) The region in which the connection should be created.
        :param pulumi.Input[_builtins.bool] route_propagation_enabled: Whether route propagation is enabled.
        :param pulumi.Input[_builtins.str] secret_id: The ID of the secret containing the pre-shared key (PSK) for the connection.
        :param pulumi.Input[_builtins.int] secret_version: The version of the secret containing the PSK.
        :param pulumi.Input[_builtins.str] status: The status of the connection.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] tags: The list of tags to apply to the connection.
        :param pulumi.Input[_builtins.str] tunnel_status: The status of the IPSec tunnel.
        :param pulumi.Input[_builtins.str] updated_at: The date and time of the last update of the connection (RFC 3339 format).
        :param pulumi.Input[_builtins.str] vpn_gateway_id: The ID of the VPN gateway to attach to the connection.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _ConnectionState.__new__(_ConnectionState)

        __props__.__dict__["bgp_config_ipv4s"] = bgp_config_ipv4s
        __props__.__dict__["bgp_config_ipv6s"] = bgp_config_ipv6s
        __props__.__dict__["bgp_session_ipv4s"] = bgp_session_ipv4s
        __props__.__dict__["bgp_session_ipv6s"] = bgp_session_ipv6s
        __props__.__dict__["bgp_status_ipv4"] = bgp_status_ipv4
        __props__.__dict__["bgp_status_ipv6"] = bgp_status_ipv6
        __props__.__dict__["created_at"] = created_at
        __props__.__dict__["customer_gateway_id"] = customer_gateway_id
        __props__.__dict__["enable_route_propagation"] = enable_route_propagation
        __props__.__dict__["esp_ciphers"] = esp_ciphers
        __props__.__dict__["ikev2_ciphers"] = ikev2_ciphers
        __props__.__dict__["initiation_policy"] = initiation_policy
        __props__.__dict__["is_ipv6"] = is_ipv6
        __props__.__dict__["name"] = name
        __props__.__dict__["organization_id"] = organization_id
        __props__.__dict__["project_id"] = project_id
        __props__.__dict__["region"] = region
        __props__.__dict__["route_propagation_enabled"] = route_propagation_enabled
        __props__.__dict__["secret_id"] = secret_id
        __props__.__dict__["secret_version"] = secret_version
        __props__.__dict__["status"] = status
        __props__.__dict__["tags"] = tags
        __props__.__dict__["tunnel_status"] = tunnel_status
        __props__.__dict__["updated_at"] = updated_at
        __props__.__dict__["vpn_gateway_id"] = vpn_gateway_id
        return Connection(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="bgpConfigIpv4s")
    def bgp_config_ipv4s(self) -> pulumi.Output[Sequence['outputs.ConnectionBgpConfigIpv4']]:
        """
        BGP configuration for IPv4. See BGP Config below.
        """
        return pulumi.get(self, "bgp_config_ipv4s")

    @_builtins.property
    @pulumi.getter(name="bgpConfigIpv6s")
    def bgp_config_ipv6s(self) -> pulumi.Output[Sequence['outputs.ConnectionBgpConfigIpv6']]:
        """
        BGP configuration for IPv6. See BGP Config below.
        """
        return pulumi.get(self, "bgp_config_ipv6s")

    @_builtins.property
    @pulumi.getter(name="bgpSessionIpv4s")
    def bgp_session_ipv4s(self) -> pulumi.Output[Sequence['outputs.ConnectionBgpSessionIpv4']]:
        """
        The BGP IPv4 session information. See BGP Session below.
        """
        return pulumi.get(self, "bgp_session_ipv4s")

    @_builtins.property
    @pulumi.getter(name="bgpSessionIpv6s")
    def bgp_session_ipv6s(self) -> pulumi.Output[Sequence['outputs.ConnectionBgpSessionIpv6']]:
        """
        The BGP IPv6 session information. See BGP Session below.
        """
        return pulumi.get(self, "bgp_session_ipv6s")

    @_builtins.property
    @pulumi.getter(name="bgpStatusIpv4")
    def bgp_status_ipv4(self) -> pulumi.Output[_builtins.str]:
        """
        The status of the BGP IPv4 session.
        """
        return pulumi.get(self, "bgp_status_ipv4")

    @_builtins.property
    @pulumi.getter(name="bgpStatusIpv6")
    def bgp_status_ipv6(self) -> pulumi.Output[_builtins.str]:
        """
        The status of the BGP IPv6 session.
        """
        return pulumi.get(self, "bgp_status_ipv6")

    @_builtins.property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> pulumi.Output[_builtins.str]:
        """
        The date and time of the creation of the connection (RFC 3339 format).
        """
        return pulumi.get(self, "created_at")

    @_builtins.property
    @pulumi.getter(name="customerGatewayId")
    def customer_gateway_id(self) -> pulumi.Output[_builtins.str]:
        """
        The ID of the customer gateway to attach to the connection.
        """
        return pulumi.get(self, "customer_gateway_id")

    @_builtins.property
    @pulumi.getter(name="enableRoutePropagation")
    def enable_route_propagation(self) -> pulumi.Output[_builtins.bool]:
        """
        Defines whether route propagation is enabled or not.
        """
        return pulumi.get(self, "enable_route_propagation")

    @_builtins.property
    @pulumi.getter(name="espCiphers")
    def esp_ciphers(self) -> pulumi.Output[Sequence['outputs.ConnectionEspCipher']]:
        """
        ESP cipher configuration for Phase 2 (data encryption). See Cipher Config below.
        """
        return pulumi.get(self, "esp_ciphers")

    @_builtins.property
    @pulumi.getter(name="ikev2Ciphers")
    def ikev2_ciphers(self) -> pulumi.Output[Sequence['outputs.ConnectionIkev2Cipher']]:
        """
        IKEv2 cipher configuration for Phase 1 (tunnel establishment). See Cipher Config below.
        """
        return pulumi.get(self, "ikev2_ciphers")

    @_builtins.property
    @pulumi.getter(name="initiationPolicy")
    def initiation_policy(self) -> pulumi.Output[_builtins.str]:
        """
        Defines who initiates the IPSec tunnel.
        """
        return pulumi.get(self, "initiation_policy")

    @_builtins.property
    @pulumi.getter(name="isIpv6")
    def is_ipv6(self) -> pulumi.Output[_builtins.bool]:
        """
        Defines IP version of the IPSec Tunnel. Defaults to `false` (IPv4).
        """
        return pulumi.get(self, "is_ipv6")

    @_builtins.property
    @pulumi.getter
    def name(self) -> pulumi.Output[_builtins.str]:
        """
        The name of the connection.
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter(name="organizationId")
    def organization_id(self) -> pulumi.Output[_builtins.str]:
        """
        The Organization ID the connection is associated with.
        """
        return pulumi.get(self, "organization_id")

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> pulumi.Output[_builtins.str]:
        """
        `project_id`) The ID of the project the connection is associated with.
        """
        return pulumi.get(self, "project_id")

    @_builtins.property
    @pulumi.getter
    def region(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        `region`) The region in which the connection should be created.
        """
        return pulumi.get(self, "region")

    @_builtins.property
    @pulumi.getter(name="routePropagationEnabled")
    def route_propagation_enabled(self) -> pulumi.Output[_builtins.bool]:
        """
        Whether route propagation is enabled.
        """
        return pulumi.get(self, "route_propagation_enabled")

    @_builtins.property
    @pulumi.getter(name="secretId")
    def secret_id(self) -> pulumi.Output[_builtins.str]:
        """
        The ID of the secret containing the pre-shared key (PSK) for the connection.
        """
        return pulumi.get(self, "secret_id")

    @_builtins.property
    @pulumi.getter(name="secretVersion")
    def secret_version(self) -> pulumi.Output[_builtins.int]:
        """
        The version of the secret containing the PSK.
        """
        return pulumi.get(self, "secret_version")

    @_builtins.property
    @pulumi.getter
    def status(self) -> pulumi.Output[_builtins.str]:
        """
        The status of the connection.
        """
        return pulumi.get(self, "status")

    @_builtins.property
    @pulumi.getter
    def tags(self) -> pulumi.Output[Optional[Sequence[_builtins.str]]]:
        """
        The list of tags to apply to the connection.
        """
        return pulumi.get(self, "tags")

    @_builtins.property
    @pulumi.getter(name="tunnelStatus")
    def tunnel_status(self) -> pulumi.Output[_builtins.str]:
        """
        The status of the IPSec tunnel.
        """
        return pulumi.get(self, "tunnel_status")

    @_builtins.property
    @pulumi.getter(name="updatedAt")
    def updated_at(self) -> pulumi.Output[_builtins.str]:
        """
        The date and time of the last update of the connection (RFC 3339 format).
        """
        return pulumi.get(self, "updated_at")

    @_builtins.property
    @pulumi.getter(name="vpnGatewayId")
    def vpn_gateway_id(self) -> pulumi.Output[_builtins.str]:
        """
        The ID of the VPN gateway to attach to the connection.
        """
        return pulumi.get(self, "vpn_gateway_id")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'ConnectionBgpConfigIpv4',
    'ConnectionBgpConfigIpv6',
    'ConnectionBgpSessionIpv4',
    'ConnectionBgpSessionIpv6',
    'ConnectionEspCipher',
    'ConnectionIkev2Cipher',
    'GatewayPublicConfig',
    'GetConnectionBgpConfigIpv4Result',
    'GetConnectionBgpConfigIpv6Result',
    'GetConnectionBgpSessionIpv4Result',
    'GetConnectionBgpSessionIpv6Result',
    'GetConnectionEspCipherResult',
    'GetConnectionIkev2CipherResult',
    'GetGatewayPublicConfigResult',
]

@pulumi.output_type
class ConnectionBgpConfigIpv4(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "routingPolicyId":
            suggest = "routing_policy_id"
        elif key == "peerPrivateIp":
            suggest = "peer_private_ip"
        elif key == "privateIp":
            suggest = "private_ip"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in ConnectionBgpConfigIpv4. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        ConnectionBgpConfigIpv4.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        ConnectionBgpConfigIpv4.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 routing_policy_id: _builtins.str,
                 peer_private_ip: Optional[_builtins.str] = None,
                 private_ip: Optional[_builtins.str] = None):
        """
        :param _builtins.str routing_policy_id: The routing policy ID used for this BGP session.
        :param _builtins.str peer_private_ip: The BGP peer IP on customer side (within the tunnel).
        :param _builtins.str private_ip: The BGP peer IP on Scaleway side (within the tunnel).
        """
        pulumi.set(__self__, "routing_policy_id", routing_policy_id)
        if peer_private_ip is not None:
            pulumi.set(__self__, "peer_private_ip", peer_private_ip)
        if private_ip is not None:
            pulumi.set(__self__, "private_ip", private_ip)

    @_builtins.property
    @pulumi.getter(name="routingPolicyId")
    def routing_policy_id(self) -> _builtins.str:
        """
        The routing policy ID used for this BGP session.
        """
        return pulumi.get(self, "routing_policy_id")

    @_builtins.property
    @pulumi.getter(name="peerPrivateIp")
    def peer_private_ip(self) -> Optional[_builtins.str]:
        """
        The BGP peer IP on customer side (within the tunnel).
        """
        return pulumi.get(self, "peer_private_ip")

    @_builtins.property
    @pulumi.getter(name="privateIp")
    def private_ip(self) -> Optional[_builtins.str]:
        """
        The BGP peer IP on Scaleway side (within the tunnel).
        """
        return pulumi.get(self, "private_ip")


@pulumi.output_type
class ConnectionBgpConfigIpv6(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "routingPolicyId":
            suggest = "routing_policy_id"
        elif key == "peerPrivateIp":
            suggest = "peer_private_ip"
        elif key == "privateIp":
            suggest = "private_ip"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in ConnectionBgpConfigIpv6. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        ConnectionBgpConfigIpv6.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        ConnectionBgpConfigIpv6.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 routing_policy_id: _builtins.str,
                 peer_private_ip: Optional[_builtins.str] = None,
                 private_ip: Optional[_builtins.str] = None):
        """
        :param _builtins.str routing_policy_id: The routing policy ID used for this BGP session.
        :param _builtins.str peer_private_ip: The BGP peer IP on customer side (within the tunnel).
        :param _builtins.str private_ip: The BGP peer IP on Scaleway side (within the tunnel).
        """
        pulumi.set(__self__, "routing_policy_id", routing_policy_id)
        if peer_private_ip is not None:
            pulumi.set(__self__, "peer_private_ip", peer_private_ip)
        if private_ip is not None:
            pulumi.set(__self__, "private_ip", private_ip)

    @_builtins.property
    @pulumi.getter(name="routingPolicyId")
    def routing_policy_id(self) -> _builtins.str:
        """
        The routing policy ID used for this BGP session.
        """
        return pulumi.get(self, "routing_policy_id")

    @_builtins.property
    @pulumi.getter(name="peerPrivateIp")
    def peer_private_ip(self) -> Optional[_builtins.str]:
        """
        The BGP peer IP on customer side (within the tunnel).
        """
        return pulumi.get(self, "peer_private_ip")

    @_builtins.property
    @pulumi.getter(name="privateIp")
    def private_ip(self) -> Optional[_builtins.str]:
        """
        The BGP peer IP on Scaleway side (within the tunnel).
        """
        return pulumi.get(self, "private_ip")


@pulumi.output_type
class ConnectionBgpSessionIpv4(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "peerPrivateIp":
            suggest = "peer_private_ip"
        elif key == "privateIp":
            suggest = "private_ip"
        elif key == "routingPolicyId":
            suggest = "routing_policy_id"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in ConnectionBgpSessionIpv4. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        ConnectionBgpSessionIpv4.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        ConnectionBgpSessionIpv4.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 peer_private_ip: Optional[_builtins.str] = None,
                 private_ip: Optional[_builtins.str] = None,
                 routing_policy_id: Optional[_builtins.str] = None):
        """
        :param _builtins.str peer_private_ip: The BGP peer IP on customer side (within the tunnel).
        :param _builtins.str private_ip: The BGP peer IP on Scaleway side (within the tunnel).
        :param _builtins.str routing_policy_id: The routing policy ID used for this BGP session.
        """
        if peer_private_ip is not None:
            pulumi.set(__self__, "peer_private_ip", peer_private_ip)
        if private_ip is not None:
            pulumi.set(__self__, "private_ip", private_ip)
        if routing_policy_id is not None:
            pulumi.set(__self__, "routing_policy_id", routing_policy_id)

    @_builtins.property
    @pulumi.getter(name="peerPrivateIp")
    def peer_private_ip(self) -> Optional[_builtins.str]:
        """
        The BGP peer IP on customer side (within the tunnel).
        """
        return pulumi.get(self, "peer_private_ip")

    @_builtins.property
    @pulumi.getter(name="privateIp")
    def private_ip(self) -> Optional[_builtins.str]:
        """
        The BGP peer IP on Scaleway side (within the tunnel).
        """
        return pulumi.get(self, "private_ip")

    @_builtins.property
    @pulumi.getter(name="routingPolicyId")
    def routing_policy_id(self) -> Optional[_builtins.str]:
        """
        The routing policy ID used for this BGP session.
        """
        return pulumi.get(self, "routing_policy_id")


@pulumi.output_type
class ConnectionBgpSessionIpv6(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "peerPrivateIp":
            suggest = "peer_private_ip"
        elif key == "privateIp":
            suggest = "private_ip"
        elif key == "routingPolicyId":
            suggest = "routing_policy_id"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in ConnectionBgpSessionIpv6. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        ConnectionBgpSessionIpv6.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        ConnectionBgpSessionIpv6.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 peer_private_ip: Optional[_builtins.str] = None,
                 private_ip: Optional[_builtins.str] = None,
                 routing_policy_id: Optional[_builtins.str] = None):
        """
        :param _builtins.str peer_private_ip: The BGP peer IP on customer side (within the tunnel).
        :param _builtins.str private_ip: The BGP peer IP on Scaleway side (within the tunnel).
        :param _builtins.str routing_policy_id: The routing policy ID used for this BGP session.
        """
        if peer_private_ip is not None:
            pulumi.set(__self__, "peer_private_ip", peer_private_ip)
        if private_ip is not None:
            pulumi.set(__self__, "private_ip", private_ip)
        if routing_policy_id is not None:
            pulumi.set(__self__, "routing_policy_id", routing_policy_id)

    @_builtins.property
    @pulumi.getter(name="peerPrivateIp")
    def peer_private_ip(self) -> Optional[_builtins.str]:
        """
        The BGP peer IP on customer side (within the tunnel).
        """
        return pulumi.get(self, "peer_private_ip")

    @_builtins.property
    @pulumi.getter(name="privateIp")
    def private_ip(self) -> Optional[_builtins.str]:
        """
        The BGP peer IP on Scaleway side (within the tunnel).
        """
        return pulumi.get(self, "private_ip")

    @_builtins.property
    @pulumi.getter(name="routingPolicyId")
    def routing_policy_id(self) -> Optional[_builtins.str]:
        """
        The routing policy ID used for this BGP session.
        """
        return pulumi.get(self, "routing_policy_id")


@pulumi.output_type
class ConnectionEspCipher(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "dhGroup":
            suggest = "dh_group"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in ConnectionEspCipher. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        ConnectionEspCipher.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        ConnectionEspCipher.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 encryption: _builtins.str,
                 dh_group: Optional[_builtins.str] = None,
                 integrity: Optional[_builtins.str] = None):
        """
        :param _builtins.str encryption: The encryption algorithm
        :param _builtins.str dh_group: The Diffie-Hellman group
        :param _builtins.str integrity: The integrity/hash algorithm
        """
        pulumi.set(__self__, "encryption", encryption)
        if dh_group is not None:
            pulumi.set(__self__, "dh_group", dh_group)
        if integrity is not None:
            pulumi.set(__self__, "integrity", integrity)

    @_builtins.property
    @pulumi.getter
    def encryption(self) -> _builtins.str:
        """
        The encryption algorithm
        """
        return pulumi.get(self, "encryption")

    @_builtins.property
    @pulumi.getter(name="dhGroup")
    def dh_group(self) -> Optional[_builtins.str]:
        """
        The Diffie-Hellman group
        """
        return pulumi.get(self, "dh_group")

    @_builtins.property
    @pulumi.getter
    def integrity(self) -> Optional[_builtins.str]:
        """
        The integrity/hash algorithm
        """
        return pulumi.get(self, "integrity")


@pulumi.output_type
class ConnectionIkev2Cipher(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "dhGroup":
            suggest = "dh_group"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in ConnectionIkev2Cipher. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        ConnectionIkev2Cipher.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        ConnectionIkev2Cipher.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 encryption: _builtins.str,
                 dh_group: Optional[_builtins.str] = None,
                 integrity: Optional[_builtins.str] = None):
        """
        :param _builtins.str encryption: The encryption algorithm
        :param _builtins.str dh_group: The Diffie-Hellman group
        :param _builtins.str integrity: The integrity/hash algorithm
        """
        pulumi.set(__self__, "encryption", encryption)
        if dh_group is not None:
            pulumi.set(__self__, "dh_group", dh_group)
        if integrity is not None:
            pulumi.set(__self__, "integrity", integrity)

    @_builtins.property
    @pulumi.getter
    def encryption(self) -> _builtins.str:
        """
        The encryption algorithm
        """
        return pulumi.get(self, "encryption")

    @_builtins.property
    @pulumi.getter(name="dhGroup")
    def dh_group(self) -> Optional[_builtins.str]:
        """
        The Diffie-Hellman group
        """
        return pulumi.get(self, "dh_group")

    @_builtins.property
    @pulumi.getter
    def integrity(self) -> Optional[_builtins.str]:
        """
        The integrity/hash algorithm
        """
        return pulumi.get(self, "integrity")


@pulumi.output_type
class GatewayPublicConfig(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "ipamIpv4Id":
            suggest = "ipam_ipv4_id"
        elif key == "ipamIpv6Id":
            suggest = "ipam_ipv6_id"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in GatewayPublicConfig. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        GatewayPublicConfig.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        GatewayPublicConfig.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 ipam_ipv4_id: Optional[_builtins.str] = None,
                 ipam_ipv6_id: Optional[_builtins.str] = None):
        """
        :param _builtins.str ipam_ipv4_id: The ID of the IPAM IPv4 address to use as the public IP for the VPN gateway.
        :param _builtins.str ipam_ipv6_id: The ID of the IPAM IPv6 address to use as the public IP for the VPN gateway.
        """
        if ipam_ipv4_id is not None:
            pulumi.set(__self__, "ipam_ipv4_id", ipam_ipv4_id)
        if ipam_ipv6_id is not None:
            pulumi.set(__self__, "ipam_ipv6_id", ipam_ipv6_id)

    @_builtins.property
    @pulumi.getter(name="ipamIpv4Id")
    def ipam_ipv4_id(self) -> Optional[_builtins.str]:
        """
        The ID of the IPAM IPv4 address to use as the public IP for the VPN gateway.
        """
        return pulumi.get(self, "ipam_ipv4_id")

    @_builtins.property
    @pulumi.getter(name="ipamIpv6Id")
    def ipam_ipv6_id(self) -> Optional[_builtins.str]:
        """
        The ID of the IPAM IPv6 address to use as the public IP for the VPN gateway.
        """
        return pulumi.get(self, "ipam_ipv6_id")


@pulumi.output_type
class GetConnectionBgpConfigIpv4Result(dict):
    def __init__(__self__, *,
                 peer_private_ip: _builtins.str,
                 private_ip: _builtins.str,
                 routing_policy_id: _builtins.str):
        """
        :param _builtins.str peer_private_ip: The BGP peer IP on customer side
        :param _builtins.str private_ip: The BGP peer IP on Scaleway side
        :param _builtins.str routing_policy_id: The ID of the routing policy to use for BGP route filtering
        """
        pulumi.set(__self__, "peer_private_ip", peer_private_ip)
        pulumi.set(__self__, "private_ip", private_ip)
        pulumi.set(__self__, "routing_policy_id", routing_policy_id)

    @_builtins.property
    @pulumi.getter(name="peerPrivateIp")
    def peer_private_ip(self) -> _builtins.str:
        """
        The BGP peer IP on customer side
        """
        return pulumi.get(self, "peer_private_ip")

    @_builtins.property
    @pulumi.getter(name="privateIp")
    def private_ip(self) -> _builtins.str:
        """
        The BGP peer IP on Scaleway side
        """
        return pulumi.get(self, "private_ip")

    @_builtins.property
    @pulumi.getter(name="routingPolicyId")
    def routing_policy_id(self) -> _builtins.str:
        """
        The ID of the routing policy to use for BGP route filtering
        """
        return pulumi.get(self, "routing_policy_id")


@pulumi.output_type
class GetConnectionBgpConfigIpv6Result(dict):
    def __init__(__self__, *,
                 peer_private_ip: _builtins.str,
                 private_ip: _builtins.str,
                 routing_policy_id: _builtins.str):
        """
        :param _builtins.str peer_private_ip: The BGP peer IP on customer side
        :param _builtins.str private_ip: The BGP peer IP on Scaleway side
        :param _builtins.str routing_policy_id: The ID of the routing policy to use for BGP route filtering
        """
        pulumi.set(__self__, "peer_private_ip", peer_private_ip)
        pulumi.set(__self__, "private_ip", private_ip)
        pulumi.set(__self__, "routing_policy_id", routing_policy_id)

    @_builtins.property
    @pulumi.getter(name="peerPrivateIp")
    def peer_private_ip(self) -> _builtins.str:
        """
        The BGP peer IP on customer side
        """
        return pulumi.get(self, "peer_private_ip")

    @_builtins.property
    @pulumi.getter(name="privateIp")
    def private_ip(self) -> _builtins.str:
        """
        The BGP peer IP on Scaleway side
        """
        return pulumi.get(self, "private_ip")

    @_builtins.property
    @pulumi.getter(name="routingPolicyId")
    def routing_policy_id(self) -> _builtins.str:
        """
        The ID of the routing policy to use for BGP route filtering
        """
        return pulumi.get(self, "routing_policy_id")


@pulumi.output_type
class GetConnectionBgpSessionIpv4Result(dict):
    def __init__(__self__, *,
                 peer_private_ip: _builtins.str,
                 private_ip: _builtins.str,
                 routing_policy_id: _builtins.str):
        """
        :param _builtins.str peer_private_ip: The BGP peer IP on customer side
        :param _builtins.str private_ip: The BGP peer IP on Scaleway side
        :param _builtins.str routing_policy_id: The routing policy ID
        """
        pulumi.set(__self__, "peer_private_ip", peer_private_ip)
        pulumi.set(__self__, "private_ip", private_ip)
        pulumi.set(__self__, "routing_policy_id", routing_policy_id)

    @_builtins.property
    @pulumi.getter(name="peerPrivateIp")
    def peer_private_ip(self) -> _builtins.str:
        """
        The BGP peer IP on customer side
        """
        return pulumi.get(self, "peer_private_ip")

    @_builtins.property
    @pulumi.getter(name="privateIp")
    def private_ip(self) -> _builtins.str:
        """
        The BGP peer IP on Scaleway side
        """
        return pulumi.get(self, "private_ip")

    @_builtins.property
    @pulumi.getter(name="routingPolicyId")
    def routing_policy_id(self) -> _builtins.str:
        """
        The routing policy ID
        """
        return pulumi.get(self, "routing_policy_id")


@pulumi.output_type
class GetConnectionBgpSessionIpv6Result(dict):
    def __init__(__self__, *,
                 peer_private_ip: _builtins.str,
                 private_ip: _builtins.str,
                 routing_policy_id: _builtins.str):
        """
        :param _builtins.str peer_private_ip: The BGP peer IP on customer side
        :param _builtins.str private_ip: The BGP peer IP on Scaleway side
        :param _builtins.str routing_policy_id: The routing policy ID
        """
        pulumi.set(__self__, "peer_private_ip", peer_private_ip)
        pulumi.set(__self__, "private_ip", private_ip)
        pulumi.set(__self__, "routing_policy_id", routing_policy_id)

    @_builtins.property
    @pulumi.getter(name="peerPrivateIp")
    def peer_private_ip(self) -> _builtins.str:
        """
        The BGP peer IP on customer side
        """
        return pulumi.get(self, "peer_private_ip")

    @_builtins.property
    @pulumi.getter(name="privateIp")
    def private_ip(self) -> _builtins.str:
        """
        The BGP peer IP on Scaleway side
        """
        return pulumi.get(self, "private_ip")

    @_builtins.property
    @pulumi.getter(name="routingPolicyId")
    def routing_policy_id(self) -> _builtins.str:
        """
        The routing policy ID
        """
        return pulumi.get(self, "routing_policy_id")


@pulumi.output_type
class GetConnectionEspCipherResult(dict):
    def __init__(__self__, *,
                 dh_group: _builtins.str,
                 encryption: _builtins.str,
                 integrity: _builtins.str):
        """
        :param _builtins.str dh_group: The Diffie-Hellman group
        :param _builtins.str encryption: The encryption algorithm
        :param _builtins.str integrity: The integrity/hash algorithm
        """
        pulumi.set(__self__, "dh_group", dh_group)
        pulumi.set(__self__, "encryption", encryption)
        pulumi.set(__self__, "integrity", integrity)

    @_builtins.property
    @pulumi.getter(name="dhGroup")
    def dh_group(self) -> _builtins.str:
        """
        The Diffie-Hellman group
        """
        return pulumi.get(self, "dh_group")

    @_builtins.property
    @pulumi.getter
    def encryption(self) -> _builtins.str:
        """
        The encryption algorithm
        """
        return pulumi.get(self, "encryption")

    @_builtins.property
    @pulumi.getter
    def integrity(self) -> _builtins.str:
        """
        The integrity/hash algorithm
        """
        return pulumi.get(self, "integrity")


@pulumi.output_type
class GetConnectionIkev2CipherResult(dict):
    def __init__(__self__, *,
                 dh_group: _builtins.str,
                 encryption: _builtins.str,
                 integrity: _builtins.str):
        """
        :param _builtins.str dh_group: The Diffie-Hellman group
        :param _builtins.str encryption: The encryption algorithm
        :param _builtins.str integrity: The integrity/hash algorithm
        """
        pulumi.set(__self__, "dh_group", dh_group)
        pulumi.set(__self__, "encryption", encryption)
        pulumi.set(__self__, "integrity", integrity)

    @_builtins.property
    @pulumi.getter(name="dhGroup")
    def dh_group(self) -> _builtins.str:
        """
        The Diffie-Hellman group
        """
        return pulumi.get(self, "dh_group")

    @_builtins.property
    @pulumi.getter
    def encryption(self) -> _builtins.str:
        """
        The encryption algorithm
        """
        return pulumi.get(self, "encryption")

    @_builtins.property
    @pulumi.getter
    def integrity(self) -> _builtins.str:
        """
        The integrity/hash algorithm
        """
        return pulumi.get(self, "integrity")


@pulumi.output_type
class GetGatewayPublicConfigResult(dict):
    def __init__(__self__, *,
                 ipam_ipv4_id: _builtins.str,
                 ipam_ipv6_id: _builtins.str):
        """
        :param _builtins.str ipam_ipv4_id: The ID of the IPAM IPv4 address to use as the public IP for the VPN gateway
        :param _builtins.str ipam_ipv6_id: The ID of the IPAM IPv6 address to use as the public IP for the VPN gateway
        """
        pulumi.set(__self__, "ipam_ipv4_id", ipam_ipv4_id)
        pulumi.set(__self__, "ipam_ipv6_id", ipam_ipv6_id)

    @_builtins.property
    @pulumi.getter(name="ipamIpv4Id")
    def ipam_ipv4_id(self) -> _builtins.str:
        """
        The ID of the IPAM IPv4 address to use as the public IP for the VPN gateway
        """
        return pulumi.get(self, "ipam_ipv4_id")

    @_builtins.property
    @pulumi.getter(name="ipamIpv6Id")
    def ipam_ipv6_id(self) -> _builtins.str:
        """
        The ID of the IPAM IPv6 address to use as the public IP for the VPN gateway
        """
        return pulumi.get(self, "ipam_ipv6_id")


